"use strict";(self.webpackChunk_JUPYTERLAB_CORE_OUTPUT=self.webpackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[1884],{31884:(e,t,r)=>{r.d(t,{o:()=>M});var s=r(82616),n=r(98332),i=r(95185),o=r(91211),a=r(92221),l=r(14869),u=r(52865),h=r(89155),c=r(940),d=r(50755);class g extends d.I{}class f extends((0,c.Um)(g)){constructor(){super(...arguments),this.proxy=document.createElement("input")}}class p extends f{readOnlyChanged(){this.proxy instanceof HTMLInputElement&&(this.proxy.readOnly=this.readOnly,this.validate())}autofocusChanged(){this.proxy instanceof HTMLInputElement&&(this.proxy.autofocus=this.autofocus,this.validate())}placeholderChanged(){this.proxy instanceof HTMLInputElement&&(this.proxy.placeholder=this.placeholder)}listChanged(){this.proxy instanceof HTMLInputElement&&(this.proxy.setAttribute("list",this.list),this.validate())}maxlengthChanged(){this.proxy instanceof HTMLInputElement&&(this.proxy.maxLength=this.maxlength,this.validate())}minlengthChanged(){this.proxy instanceof HTMLInputElement&&(this.proxy.minLength=this.minlength,this.validate())}patternChanged(){this.proxy instanceof HTMLInputElement&&(this.proxy.pattern=this.pattern,this.validate())}sizeChanged(){this.proxy instanceof HTMLInputElement&&(this.proxy.size=this.size)}spellcheckChanged(){this.proxy instanceof HTMLInputElement&&(this.proxy.spellcheck=this.spellcheck)}connectedCallback(){super.connectedCallback(),this.validate(),this.autofocus&&o.SO.queueUpdate((()=>{this.focus()}))}validate(){super.validate(this.control)}handleTextInput(){this.value=this.control.value}handleClearInput(){this.value="",this.control.focus(),this.handleChange()}handleChange(){this.$emit("change")}}(0,i.gn)([(0,n.Lj)({attribute:"readonly",mode:"boolean"})],p.prototype,"readOnly",void 0),(0,i.gn)([(0,n.Lj)({mode:"boolean"})],p.prototype,"autofocus",void 0),(0,i.gn)([n.Lj],p.prototype,"placeholder",void 0),(0,i.gn)([n.Lj],p.prototype,"list",void 0),(0,i.gn)([(0,n.Lj)({converter:n.Id})],p.prototype,"maxlength",void 0),(0,i.gn)([(0,n.Lj)({converter:n.Id})],p.prototype,"minlength",void 0),(0,i.gn)([n.Lj],p.prototype,"pattern",void 0),(0,i.gn)([(0,n.Lj)({converter:n.Id})],p.prototype,"size",void 0),(0,i.gn)([(0,n.Lj)({mode:"boolean"})],p.prototype,"spellcheck",void 0),(0,i.gn)([a.LO],p.prototype,"defaultSlottedNodes",void 0);class b{}(0,h.e)(b,l.v),(0,h.e)(p,u.hW,b);var v=r(25269),m=r(17832),y=r(62564);function w(e,t,r){return e.nodeType!==Node.TEXT_NODE||"string"==typeof e.nodeValue&&!!e.nodeValue.trim().length}var C=r(12634),x=r(27002),V=r(53405),F=r(87206),O=r(78885),D=r(61424),k=r(98242),S=r(30550),$=r(13370);const T=C.i`
  ${(0,O.j)("inline-block")} :host {
    font-family: ${F.SV};
    outline: none;
    user-select: none;
  }

  .root {
    box-sizing: border-box;
    position: relative;
    display: flex;
    flex-direction: row;
    color: ${F.hY};
    background: ${F._B};
    border-radius: calc(${F.UW} * 1px);
    border: calc(${F.H} * 1px) solid ${F.P0};
    height: calc(${$.i} * 1px);
  }

  :host([aria-invalid='true']) .root {
    border-color: ${F.a6};
  }

  .control {
    -webkit-appearance: none;
    font: inherit;
    background: transparent;
    border: 0;
    color: inherit;
    height: calc(100% - 4px);
    width: 100%;
    margin-top: auto;
    margin-bottom: auto;
    border: none;
    padding: 0 calc(${F._5} * 2px + 1px);
    font-size: ${F.cS};
    line-height: ${F.RU};
  }

  .control:hover,
  .control:${V.b},
  .control:disabled,
  .control:active {
    outline: none;
  }

  .label {
    display: block;
    color: ${F.hY};
    cursor: pointer;
    font-size: ${F.cS};
    line-height: ${F.RU};
    margin-bottom: 4px;
  }

  .label__hidden {
    display: none;
    visibility: hidden;
  }

  .start,
  .end {
    margin: auto;
    fill: currentcolor;
  }

  ::slotted(svg) {
    /* TODO: adaptive typography https://github.com/microsoft/fast/issues/2432 */
    width: 16px;
    height: 16px;
  }

  .start {
    margin-inline-start: 11px;
  }

  .end {
    margin-inline-end: 11px;
  }

  :host(:hover:not([disabled])) .root {
    background: ${F.Tm};
    border-color: ${F.Dg};
  }

  :host([aria-invalid='true']:hover:not([disabled])) .root {
    border-color: ${F.ek};
  }

  :host(:active:not([disabled])) .root {
    background: ${F.Tm};
    border-color: ${F.hP};
  }

  :host([aria-invalid='true']:active:not([disabled])) .root {
    border-color: ${F.GB};
  }

  :host(:focus-within:not([disabled])) .root {
    border-color: ${F.D8};
    box-shadow: 0 0 0 calc((${F.vx} - ${F.H}) * 1px)
      ${F.D8};
  }

  :host([aria-invalid='true']:focus-within:not([disabled])) .root {
    border-color: ${F.mH};
    box-shadow: 0 0 0 calc((${F.vx} - ${F.H}) * 1px)
      ${F.mH};
  }

  :host([appearance='filled']) .root {
    background: ${F.wF};
  }

  :host([appearance='filled']:hover:not([disabled])) .root {
    background: ${F.Xi};
  }

  :host([disabled]) .label,
  :host([readonly]) .label,
  :host([readonly]) .control,
  :host([disabled]) .control {
    cursor: ${D.H};
  }

  :host([disabled]) {
    opacity: ${F.VF};
  }

  :host([disabled]) .control {
    border-color: ${F.ak};
  }
`.withBehaviors((0,k.vF)(C.i`
    .root,
    :host([appearance='filled']) .root {
      forced-color-adjust: none;
      background: ${S.H.Field};
      border-color: ${S.H.FieldText};
    }
    :host([aria-invalid='true']) .root {
      border-style: dashed;
    }
    :host(:hover:not([disabled])) .root,
    :host([appearance='filled']:hover:not([disabled])) .root,
    :host([appearance='filled']:hover) .root {
      background: ${S.H.Field};
      border-color: ${S.H.Highlight};
    }
    .start,
    .end {
      fill: currentcolor;
    }
    :host([disabled]) {
      opacity: 1;
    }
    :host([disabled]) .root,
    :host([appearance='filled']:hover[disabled]) .root {
      border-color: ${S.H.GrayText};
      background: ${S.H.Field};
    }
    :host(:focus-within:enabled) .root {
      border-color: ${S.H.Highlight};
      box-shadow: 0 0 0 calc((${F.vx} - ${F.H}) * 1px)
        ${S.H.Highlight};
    }
    input::placeholder {
      color: ${S.H.GrayText};
    }
  `)),P=x.DesignToken.create("clear-button-hover").withDefault((e=>{const t=F.DF.getValueFor(e),r=F.At.getValueFor(e);return t.evaluate(e,r.evaluate(e).hover).hover})),L=x.DesignToken.create("clear-button-active").withDefault((e=>{const t=F.DF.getValueFor(e),r=F.At.getValueFor(e);return t.evaluate(e,r.evaluate(e).hover).active}));class R extends p{constructor(){super(...arguments),this.appearance="outline"}}(0,s.gn)([n.Lj],R.prototype,"appearance",void 0);const N=R.compose({baseName:"search",baseClass:p,template:(e,t)=>v.d`
    <template
        class="
            ${e=>e.readOnly?"readonly":""}
        "
    >
        <label
            part="label"
            for="control"
            class="${e=>e.defaultSlottedNodes&&e.defaultSlottedNodes.length?"label":"label label__hidden"}"
        >
            <slot
                ${(0,m.Q)({property:"defaultSlottedNodes",filter:w})}
            ></slot>
        </label>
        <div class="root" part="root" ${(0,y.i)("root")}>
            ${(0,u.m9)(e,t)}
            <div class="input-wrapper" part="input-wrapper">
                <input
                    class="control"
                    part="control"
                    id="control"
                    @input="${e=>e.handleTextInput()}"
                    @change="${e=>e.handleChange()}"
                    ?autofocus="${e=>e.autofocus}"
                    ?disabled="${e=>e.disabled}"
                    list="${e=>e.list}"
                    maxlength="${e=>e.maxlength}"
                    minlength="${e=>e.minlength}"
                    pattern="${e=>e.pattern}"
                    placeholder="${e=>e.placeholder}"
                    ?readonly="${e=>e.readOnly}"
                    ?required="${e=>e.required}"
                    size="${e=>e.size}"
                    ?spellcheck="${e=>e.spellcheck}"
                    :value="${e=>e.value}"
                    type="search"
                    aria-atomic="${e=>e.ariaAtomic}"
                    aria-busy="${e=>e.ariaBusy}"
                    aria-controls="${e=>e.ariaControls}"
                    aria-current="${e=>e.ariaCurrent}"
                    aria-describedby="${e=>e.ariaDescribedby}"
                    aria-details="${e=>e.ariaDetails}"
                    aria-disabled="${e=>e.ariaDisabled}"
                    aria-errormessage="${e=>e.ariaErrormessage}"
                    aria-flowto="${e=>e.ariaFlowto}"
                    aria-haspopup="${e=>e.ariaHaspopup}"
                    aria-hidden="${e=>e.ariaHidden}"
                    aria-invalid="${e=>e.ariaInvalid}"
                    aria-keyshortcuts="${e=>e.ariaKeyshortcuts}"
                    aria-label="${e=>e.ariaLabel}"
                    aria-labelledby="${e=>e.ariaLabelledby}"
                    aria-live="${e=>e.ariaLive}"
                    aria-owns="${e=>e.ariaOwns}"
                    aria-relevant="${e=>e.ariaRelevant}"
                    aria-roledescription="${e=>e.ariaRoledescription}"
                    ${(0,y.i)("control")}
                />
                <slot name="close-button">
                    <button
                        class="clear-button ${e=>e.value?"":"clear-button__hidden"}"
                        part="clear-button"
                        tabindex="-1"
                        @click=${e=>e.handleClearInput()}
                    >
                        <slot name="close-glyph">
                            <svg
                                width="9"
                                height="9"
                                viewBox="0 0 9 9"
                                xmlns="http://www.w3.org/2000/svg"
                            >
                                <path
                                    d="M0.146447 0.146447C0.338683 -0.0478972 0.645911 -0.0270359 0.853553 0.146447L4.5 3.793L8.14645 0.146447C8.34171 -0.0488155 8.65829 -0.0488155 8.85355 0.146447C9.04882 0.341709 9.04882 0.658291 8.85355 0.853553L5.207 4.5L8.85355 8.14645C9.05934 8.35223 9.03129 8.67582 8.85355 8.85355C8.67582 9.03129 8.35409 9.02703 8.14645 8.85355L4.5 5.207L0.853553 8.85355C0.658291 9.04882 0.341709 9.04882 0.146447 8.85355C-0.0488155 8.65829 -0.0488155 8.34171 0.146447 8.14645L3.793 4.5L0.146447 0.853553C-0.0268697 0.680237 -0.0457894 0.34079 0.146447 0.146447Z"
                                />
                            </svg>
                        </slot>
                    </button>
                </slot>
            </div>
            ${(0,u.LC)(e,t)}
        </div>
    </template>
`,styles:(e,t)=>C.i`
  ${T}

  .control::-webkit-search-cancel-button {
    -webkit-appearance: none;
  }

  .control:hover,
    .control:${V.b},
    .control:disabled,
    .control:active {
    outline: none;
  }

  .clear-button {
    height: calc(100% - 2px);
    opacity: 0;
    margin: 1px;
    background: transparent;
    color: ${F.hY};
    fill: currentcolor;
    border: none;
    border-radius: calc(${F.UW} * 1px);
    min-width: calc(${$.i} * 1px);
    font-size: ${F.cS};
    line-height: ${F.RU};
    outline: none;
    font-family: ${F.SV};
    padding: 0 calc((10 + (${F._5} * 2 * ${F.hV})) * 1px);
  }

  .clear-button:hover {
    background: ${F.Qp};
  }

  .clear-button:active {
    background: ${F.sG};
  }

  :host([appearance='filled']) .clear-button:hover {
    background: ${P};
  }

  :host([appearance='filled']) .clear-button:active {
    background: ${L};
  }

  .input-wrapper {
    display: flex;
    position: relative;
    width: 100%;
  }

  .start,
  .end {
    display: flex;
    margin: 1px;
    fill: currentcolor;
  }

  ::slotted([slot='end']) {
    height: 100%;
  }

  .end {
    margin-inline-end: 1px;
    height: calc(100% - 2px);
  }

  ::slotted(svg) {
    /* TODO: adaptive typography https://github.com/microsoft/fast/issues/2432 */
    width: 16px;
    height: 16px;
    margin-inline-end: 11px;
    margin-inline-start: 11px;
    margin-top: auto;
    margin-bottom: auto;
  }

  .clear-button__hidden {
    opacity: 0;
  }

  :host(:hover:not([disabled], [readOnly])) .clear-button,
  :host(:active:not([disabled], [readOnly])) .clear-button,
  :host(:focus-within:not([disabled], [readOnly])) .clear-button {
    opacity: 1;
  }

  :host(:hover:not([disabled], [readOnly])) .clear-button__hidden,
  :host(:active:not([disabled], [readOnly])) .clear-button__hidden,
  :host(:focus-within:not([disabled], [readOnly])) .clear-button__hidden {
    opacity: 0;
  }
`,shadowOptions:{delegatesFocus:!0}}),M=(0,r(50450).r)(N(),{events:{onChange:"change",onInput:"input"}});M.displayName="Jupyter.Search"},50450:(e,t,r)=>{r.d(t,{r:()=>b});var s=r(68866),n=r(74855),i=r(92221),o=r(50755);const a=new Set(["children","localName","ref","style","className"]),l=Object.freeze(Object.create(null)),u="_default",h=new Map;function c(e,t){if(!t.name){const r=n.W.forType(e);if(!r)throw new Error("React wrappers must wrap a FASTElement or be configured with a name.");t.name=r.name}return t.name}function d(e){return e.events||(e.events={})}function g(e,t,r){return!a.has(r)||(console.warn(`${c(e,t)} contains property ${r} which is a React reserved property. It will be used by React and not set on the element.`),!1)}var f=r(78156),p=r.n(f);const{wrap:b}=function(e,t){let r=[];return{wrap:function(s,n={}){var a,f;s instanceof o.R&&(t?t.register(s):r.push(s),s=s.type);const p=h.get(s);if(p){const e=p.get(null!==(a=n.name)&&void 0!==a?a:u);if(e)return e}class b extends e.Component{constructor(){super(...arguments),this._element=null}_updateElement(e){const t=this._element;if(null===t)return;const r=this.props,s=e||l,i=d(n);for(const e in this._elementProps){const n=r[e],o=i[e];if(void 0===o)t[e]=n;else{const r=s[e];if(n===r)continue;void 0!==r&&t.removeEventListener(o,r),void 0!==n&&t.addEventListener(o,n)}}}componentDidMount(){this._updateElement()}componentDidUpdate(e){this._updateElement(e)}render(){const t=this.props.__forwardedRef;void 0!==this._ref&&this._userRef===t||(this._ref=e=>{null===this._element&&(this._element=e),null!==t&&function(e,t){"function"==typeof e?e(t):e.current=t}(t,e),this._userRef=t});const r={ref:this._ref},o=this._elementProps={},a=function(e,t){if(!t.keys)if(t.properties)t.keys=new Set(t.properties.concat(Object.keys(d(t))));else{const r=new Set(Object.keys(d(t))),s=i.y$.getAccessors(e.prototype);if(s.length>0)for(const n of s)g(e,t,n.name)&&r.add(n.name);else for(const s in e.prototype)!(s in HTMLElement.prototype)&&g(e,t,s)&&r.add(s);t.keys=r}return t.keys}(s,n),l=this.props;for(const e in l){const t=l[e];a.has(e)?o[e]=t:r["className"===e?"class":e]=t}return e.createElement(c(s,n),r)}}const v=e.forwardRef(((t,r)=>e.createElement(b,Object.assign(Object.assign({},t),{__forwardedRef:r}),null==t?void 0:t.children)));return h.has(s)||h.set(s,new Map),h.get(s).set(null!==(f=n.name)&&void 0!==f?f:u,v),v},registry:{register(e,...t){r.forEach((r=>r.register(e,...t))),r=[]}}}}(p(),(0,s.W)())},83571:(e,t,r)=>{r.d(t,{m:()=>a,w:()=>o});var s=r(616),n=r(76962),i=r(38844);const o=Object.freeze({create:(e,t,r)=>new l(e,t,r),from:e=>new l(e.r,e.g,e.b)});function a(e){const t={r:0,g:0,b:0,toColorString:()=>"",contrast:()=>0,relativeLuminance:0};for(const r in t)if(typeof t[r]!=typeof e[r])return!1;return!0}class l extends s.h{constructor(e,t,r){super(e,t,r,1),this.toColorString=this.toStringHexRGB,this.contrast=i.$.bind(null,this),this.createCSS=this.toColorString,this.relativeLuminance=(0,n.hM)(this)}static fromObject(e){return new l(e.r,e.g,e.b)}}},79892:(e,t,r)=>{r.d(t,{C:()=>n,h:()=>i});var s=r(83571);function n(e){return s.w.create(e,e,e)}const i={LightMode:1,DarkMode:.23}},90859:(e,t,r)=>{r.d(t,{_:()=>n});const s=(-.1+Math.sqrt(.21))/2;function n(e){return e.relativeLuminance<=s}},38844:(e,t,r)=>{function s(e,t){const r=e.relativeLuminance>t.relativeLuminance?e:t,s=e.relativeLuminance>t.relativeLuminance?t:e;return(r.relativeLuminance+.05)/(s.relativeLuminance+.05)}r.d(t,{$:()=>s})},87206:(e,t,r)=>{r.d(t,{z:()=>$e,UE:()=>ze,D8:()=>qe,OC:()=>He,B2:()=>K,Av:()=>_e,VN:()=>tt,D9:()=>et,go:()=>Je,nf:()=>H,q2:()=>z,SV:()=>_,UW:()=>q,hV:()=>U,_5:()=>W,VF:()=>Z,S_:()=>kt,GB:()=>Lt,mH:()=>Rt,ek:()=>Pt,a6:()=>Tt,DV:()=>Bt,If:()=>je,yG:()=>yt,vx:()=>Y,Pp:()=>Ye,lJ:()=>Ge,w4:()=>Ze,z4:()=>ke,Gy:()=>it,Xi:()=>nt,Tm:()=>lt,_B:()=>at,ab:()=>vt,At:()=>rt,wF:()=>st,sG:()=>ct,Qp:()=>ht,DF:()=>ut,hP:()=>pt,Nz:()=>bt,Dg:()=>ft,P0:()=>gt,hY:()=>Vt,ak:()=>Ot,H:()=>G,cS:()=>X,RU:()=>Q});var s,n=r(27002),i=r(6618),o=r(58902),a=r(616),l=r(76962),u=r(29087);function h(e,t,r=18){const s=(0,l.$2)(e);let n=s.c+t*r;return n<0&&(n=0),(0,l.KW)(new u.t(s.l,n,s.h))}function c(e,t){return e*t}function d(e,t){return new a.h(c(e.r,t.r),c(e.g,t.g),c(e.b,t.b),1)}function g(e,t){return e<.5?(0,o.uZ)(2*t*e,0,1):(0,o.uZ)(1-2*(1-t)*(1-e),0,1)}function f(e,t){return new a.h(g(e.r,t.r),g(e.g,t.g),g(e.b,t.b),1)}!function(e){e[e.Burn=0]="Burn",e[e.Color=1]="Color",e[e.Darken=2]="Darken",e[e.Dodge=3]="Dodge",e[e.Lighten=4]="Lighten",e[e.Multiply=5]="Multiply",e[e.Overlay=6]="Overlay",e[e.Screen=7]="Screen"}(s||(s={}));var p,b=r(77727),v=r(25700),m=r(70656),y=r(82800);function w(e,t,r,s){if(isNaN(e)||e<=0)return r;if(e>=1)return s;switch(t){case p.HSL:return(0,l.hP)(function(e,t,r){return isNaN(e)||e<=0?t:e>=1?r:new b.H((0,o.AG)(e,t.h,r.h),(0,o.t7)(e,t.s,r.s),(0,o.t7)(e,t.l,r.l))}(e,(0,l.lw)(r),(0,l.lw)(s)));case p.HSV:return(0,l.iI)(function(e,t,r){return isNaN(e)||e<=0?t:e>=1?r:new v.T((0,o.AG)(e,t.h,r.h),(0,o.t7)(e,t.s,r.s),(0,o.t7)(e,t.v,r.v))}(e,(0,l.T8)(r),(0,l.T8)(s)));case p.XYZ:return(0,l.rD)(function(e,t,r){return isNaN(e)||e<=0?t:e>=1?r:new y.x((0,o.t7)(e,t.x,r.x),(0,o.t7)(e,t.y,r.y),(0,o.t7)(e,t.z,r.z))}(e,(0,l.zP)(r),(0,l.zP)(s)));case p.LAB:return(0,l.DR)(function(e,t,r){return isNaN(e)||e<=0?t:e>=1?r:new m.R((0,o.t7)(e,t.l,r.l),(0,o.t7)(e,t.a,r.a),(0,o.t7)(e,t.b,r.b))}(e,(0,l.v1)(r),(0,l.v1)(s)));case p.LCH:return(0,l.KW)(function(e,t,r){return isNaN(e)||e<=0?t:e>=1?r:new u.t((0,o.t7)(e,t.l,r.l),(0,o.t7)(e,t.c,r.c),(0,o.AG)(e,t.h,r.h))}(e,(0,l.$2)(r),(0,l.$2)(s)));default:return function(e,t,r){return isNaN(e)||e<=0?t:e>=1?r:new a.h((0,o.t7)(e,t.r,r.r),(0,o.t7)(e,t.g,r.g),(0,o.t7)(e,t.b,r.b),(0,o.t7)(e,t.a,r.a))}(e,r,s)}}!function(e){e[e.RGB=0]="RGB",e[e.HSL=1]="HSL",e[e.HSV=2]="HSV",e[e.XYZ=3]="XYZ",e[e.LAB=4]="LAB",e[e.LCH=5]="LCH"}(p||(p={}));class C{constructor(e){if(null==e||0===e.length)throw new Error("The stops argument must be non-empty");this.stops=this.sortColorScaleStops(e)}static createBalancedColorScale(e){if(null==e||0===e.length)throw new Error("The colors argument must be non-empty");const t=new Array(e.length);for(let r=0;r<e.length;r++)0===r?t[r]={color:e[r],position:0}:r===e.length-1?t[r]={color:e[r],position:1}:t[r]={color:e[r],position:r*(1/(e.length-1))};return new C(t)}getColor(e,t=p.RGB){if(1===this.stops.length)return this.stops[0].color;if(e<=0)return this.stops[0].color;if(e>=1)return this.stops[this.stops.length-1].color;let r=0;for(let t=0;t<this.stops.length;t++)this.stops[t].position<=e&&(r=t);let s=r+1;return s>=this.stops.length&&(s=this.stops.length-1),w((e-this.stops[r].position)*(1/(this.stops[s].position-this.stops[r].position)),t,this.stops[r].color,this.stops[s].color)}trim(e,t,r=p.RGB){if(e<0||t>1||t<e)throw new Error("Invalid bounds");if(e===t)return new C([{color:this.getColor(e,r),position:0}]);const s=[];for(let r=0;r<this.stops.length;r++)this.stops[r].position>=e&&this.stops[r].position<=t&&s.push(this.stops[r]);if(0===s.length)return new C([{color:this.getColor(e),position:e},{color:this.getColor(t),position:t}]);s[0].position!==e&&s.unshift({color:this.getColor(e),position:e}),s[s.length-1].position!==t&&s.push({color:this.getColor(t),position:t});const n=t-e,i=new Array(s.length);for(let t=0;t<s.length;t++)i[t]={color:s[t].color,position:(s[t].position-e)/n};return new C(i)}findNextColor(e,t,r=!1,s=p.RGB,n=.005,i=32){isNaN(e)||e<=0?e=0:e>=1&&(e=1);const o=this.getColor(e,s),a=r?0:1,u=this.getColor(a,s);if((0,l.wo)(o,u)<=t)return a;let h=r?0:e,c=r?e:0,d=a,g=0;for(;g<=i;){d=Math.abs(c-h)/2+h;const e=this.getColor(d,s),i=(0,l.wo)(o,e);if(Math.abs(i-t)<=n)return d;i>t?r?h=d:c=d:r?c=d:h=d,g++}return d}clone(){const e=new Array(this.stops.length);for(let t=0;t<e.length;t++)e[t]={color:this.stops[t].color,position:this.stops[t].position};return new C(e)}sortColorScaleStops(e){return e.sort(((e,t)=>{const r=e.position,s=t.position;return r<s?-1:r>s?1:0}))}}var x=r(93484);class V{constructor(e){this.config=Object.assign({},V.defaultPaletteConfig,e),this.palette=[],this.updatePaletteColors()}updatePaletteGenerationValues(e){let t=!1;for(const r in e)this.config[r]&&(this.config[r].equalValue?this.config[r].equalValue(e[r])||(this.config[r]=e[r],t=!0):e[r]!==this.config[r]&&(this.config[r]=e[r],t=!0));return t&&this.updatePaletteColors(),t}updatePaletteColors(){const e=this.generatePaletteColorScale();for(let t=0;t<this.config.steps;t++)this.palette[t]=e.getColor(t/(this.config.steps-1),this.config.interpolationMode)}generatePaletteColorScale(){const e=(0,l.lw)(this.config.baseColor),t=new C([{position:0,color:this.config.scaleColorLight},{position:.5,color:this.config.baseColor},{position:1,color:this.config.scaleColorDark}]).trim(this.config.clipLight,1-this.config.clipDark);let r=t.getColor(0),s=t.getColor(1);if(e.s>=this.config.saturationAdjustmentCutoff&&(r=h(r,this.config.saturationLight),s=h(s,this.config.saturationDark)),0!==this.config.multiplyLight){const e=d(this.config.baseColor,r);r=w(this.config.multiplyLight,this.config.interpolationMode,r,e)}if(0!==this.config.multiplyDark){const e=d(this.config.baseColor,s);s=w(this.config.multiplyDark,this.config.interpolationMode,s,e)}if(0!==this.config.overlayLight){const e=f(this.config.baseColor,r);r=w(this.config.overlayLight,this.config.interpolationMode,r,e)}if(0!==this.config.overlayDark){const e=f(this.config.baseColor,s);s=w(this.config.overlayDark,this.config.interpolationMode,s,e)}return this.config.baseScalePosition?this.config.baseScalePosition<=0?new C([{position:0,color:this.config.baseColor},{position:1,color:s.clamp()}]):this.config.baseScalePosition>=1?new C([{position:0,color:r.clamp()},{position:1,color:this.config.baseColor}]):new C([{position:0,color:r.clamp()},{position:this.config.baseScalePosition,color:this.config.baseColor},{position:1,color:s.clamp()}]):new C([{position:0,color:r.clamp()},{position:.5,color:this.config.baseColor},{position:1,color:s.clamp()}])}}V.defaultPaletteConfig={baseColor:(0,x.in)("#808080"),steps:11,interpolationMode:p.RGB,scaleColorLight:new a.h(1,1,1,1),scaleColorDark:new a.h(0,0,0,1),clipLight:.185,clipDark:.16,saturationAdjustmentCutoff:.05,saturationLight:.35,saturationDark:1.25,overlayLight:0,overlayDark:.25,multiplyLight:0,multiplyDark:0,baseScalePosition:.5},V.greyscalePaletteConfig={baseColor:(0,x.in)("#808080"),steps:11,interpolationMode:p.RGB,scaleColorLight:new a.h(1,1,1,1),scaleColorDark:new a.h(0,0,0,1),clipLight:0,clipDark:0,saturationAdjustmentCutoff:0,saturationLight:0,saturationDark:0,overlayLight:0,overlayDark:0,multiplyLight:0,multiplyDark:0,baseScalePosition:.5},V.defaultPaletteConfig.scaleColorLight,V.defaultPaletteConfig.scaleColorDark;class F{constructor(e){this.palette=[],this.config=Object.assign({},F.defaultPaletteConfig,e),this.regenPalettes()}regenPalettes(){let e=this.config.steps;(isNaN(e)||e<3)&&(e=3);const t=.14,r=new a.h(t,t,t,1),s=new V(Object.assign(Object.assign({},V.greyscalePaletteConfig),{baseColor:r,baseScalePosition:86/94,steps:e})).palette,n=((0,l.rp)(this.config.baseColor)+(0,l.lw)(this.config.baseColor).l)/2,i=this.matchRelativeLuminanceIndex(n,s)/(e-1),o=this.matchRelativeLuminanceIndex(t,s)/(e-1),u=(0,l.lw)(this.config.baseColor),h=(0,l.hP)(b.H.fromObject({h:u.h,s:u.s,l:t})),c=(0,l.hP)(b.H.fromObject({h:u.h,s:u.s,l:.06})),d=new Array(5);d[0]={position:0,color:new a.h(1,1,1,1)},d[1]={position:i,color:this.config.baseColor},d[2]={position:o,color:h},d[3]={position:.99,color:c},d[4]={position:1,color:new a.h(0,0,0,1)};const g=new C(d);this.palette=new Array(e);for(let t=0;t<e;t++){const r=g.getColor(t/(e-1),p.RGB);this.palette[t]=r}}matchRelativeLuminanceIndex(e,t){let r=Number.MAX_VALUE,s=0,n=0;const i=t.length;for(;n<i;n++){const i=Math.abs((0,l.rp)(t[n])-e);i<r&&(r=i,s=n)}return s}}F.defaultPaletteConfig={baseColor:(0,x.in)("#808080"),steps:94};var O=r(83571);function D(e,t,r=0,s=e.length-1){if(s===r)return e[r];const n=Math.floor((s-r)/2)+r;return t(e[n])?D(e,t,r,n):D(e,t,n+1,s)}var k=r(90859);function S(e){return(0,k._)(e)?-1:1}var $=r(38844);const T=Object.freeze({create:function(e,t,r){return"number"==typeof e?T.from(O.w.create(e,t,r)):T.from(e)},from:function(e){return(0,O.m)(e)?P.from(e):P.from(O.w.create(e.r,e.g,e.b))}});class P{constructor(e,t){this.closestIndexCache=new Map,this.source=e,this.swatches=t,this.reversedSwatches=Object.freeze([...this.swatches].reverse()),this.lastIndex=this.swatches.length-1}colorContrast(e,t,r,s){void 0===r&&(r=this.closestIndexOf(e));let n=this.swatches;const i=this.lastIndex;let o=r;return void 0===s&&(s=S(e)),-1===s&&(n=this.reversedSwatches,o=i-o),D(n,(r=>(0,$.$)(e,r)>=t),o,i)}get(e){return this.swatches[e]||this.swatches[(0,o.uZ)(e,0,this.lastIndex)]}closestIndexOf(e){if(this.closestIndexCache.has(e.relativeLuminance))return this.closestIndexCache.get(e.relativeLuminance);let t=this.swatches.indexOf(e);if(-1!==t)return this.closestIndexCache.set(e.relativeLuminance,t),t;const r=this.swatches.reduce(((t,r)=>Math.abs(r.relativeLuminance-e.relativeLuminance)<Math.abs(t.relativeLuminance-e.relativeLuminance)?r:t));return t=this.swatches.indexOf(r),this.closestIndexCache.set(e.relativeLuminance,t),t}static from(e){return new P(e,Object.freeze(new F({baseColor:a.h.fromObject(e)}).palette.map((e=>{const t=(0,x.in)(e.toStringHexRGB());return O.w.create(t.r,t.g,t.b)}))))}}const L=O.w.create(1,1,1),R=O.w.create(0,0,0),N=O.w.from((0,x.in)("#808080")),M=O.w.from((0,x.in)("#DA1A5F")),A=O.w.from((0,x.in)("#D32F2F"));var I=r(79892);function j(e,t,r,s,n,i){return Math.max(e.closestIndexOf((0,I.C)(t))+r,s,n,i)}const{create:B}=n.DesignToken;function E(e){return n.DesignToken.create({name:e,cssCustomPropertyName:null})}const _=B("body-font").withDefault('aktiv-grotesk, "Segoe UI", Arial, Helvetica, sans-serif'),H=B("base-height-multiplier").withDefault(10),z=(B("base-horizontal-spacing-multiplier").withDefault(3),B("base-layer-luminance").withDefault(I.h.DarkMode)),q=B("control-corner-radius").withDefault(4),U=B("density").withDefault(0),W=B("design-unit").withDefault(4),Z=(B("direction").withDefault(i.N.ltr),B("disabled-opacity").withDefault(.4)),G=B("stroke-width").withDefault(1),Y=B("focus-stroke-width").withDefault(2),X=B("type-ramp-base-font-size").withDefault("14px"),Q=B("type-ramp-base-line-height").withDefault("20px"),K=(B("type-ramp-minus-1-font-size").withDefault("12px"),B("type-ramp-minus-1-line-height").withDefault("16px"),B("type-ramp-minus-2-font-size").withDefault("10px"),B("type-ramp-minus-2-line-height").withDefault("16px"),B("type-ramp-plus-1-font-size").withDefault("16px"),B("type-ramp-plus-1-line-height").withDefault("24px"),B("type-ramp-plus-2-font-size").withDefault("20px"),B("type-ramp-plus-2-line-height").withDefault("28px"),B("type-ramp-plus-3-font-size").withDefault("28px"),B("type-ramp-plus-3-line-height").withDefault("36px"),B("type-ramp-plus-4-font-size").withDefault("34px"),B("type-ramp-plus-4-line-height").withDefault("44px"),B("type-ramp-plus-5-font-size").withDefault("46px"),B("type-ramp-plus-5-line-height").withDefault("56px"),B("type-ramp-plus-6-font-size").withDefault("60px"),B("type-ramp-plus-6-line-height").withDefault("72px"),E("accent-fill-rest-delta").withDefault(0),E("accent-fill-hover-delta").withDefault(4)),J=E("accent-fill-active-delta").withDefault(-5),ee=E("accent-fill-focus-delta").withDefault(0),te=E("accent-foreground-rest-delta").withDefault(0),re=E("accent-foreground-hover-delta").withDefault(6),se=E("accent-foreground-active-delta").withDefault(-4),ne=E("accent-foreground-focus-delta").withDefault(0),ie=E("neutral-fill-rest-delta").withDefault(7),oe=E("neutral-fill-hover-delta").withDefault(10),ae=E("neutral-fill-active-delta").withDefault(5),le=E("neutral-fill-focus-delta").withDefault(0),ue=E("neutral-fill-input-rest-delta").withDefault(0),he=E("neutral-fill-input-hover-delta").withDefault(0),ce=E("neutral-fill-input-active-delta").withDefault(0),de=E("neutral-fill-input-focus-delta").withDefault(0),ge=E("neutral-fill-stealth-rest-delta").withDefault(0),fe=E("neutral-fill-stealth-hover-delta").withDefault(5),pe=E("neutral-fill-stealth-active-delta").withDefault(3),be=E("neutral-fill-stealth-focus-delta").withDefault(0),ve=E("neutral-fill-strong-rest-delta").withDefault(0),me=E("neutral-fill-strong-hover-delta").withDefault(8),ye=E("neutral-fill-strong-active-delta").withDefault(-5),we=E("neutral-fill-strong-focus-delta").withDefault(0),Ce=E("neutral-fill-layer-rest-delta").withDefault(3),xe=E("neutral-stroke-rest-delta").withDefault(25),Ve=E("neutral-stroke-hover-delta").withDefault(40),Fe=E("neutral-stroke-active-delta").withDefault(16),Oe=E("neutral-stroke-focus-delta").withDefault(25),De=E("neutral-stroke-divider-rest-delta").withDefault(8),ke=B("neutral-color").withDefault(N),Se=E("neutral-palette").withDefault((e=>T.from(ke.getValueFor(e)))),$e=B("accent-color").withDefault(M),Te=E("accent-palette").withDefault((e=>T.from($e.getValueFor(e)))),Pe=E("neutral-layer-card-container-recipe").withDefault({evaluate:e=>{return t=Se.getValueFor(e),r=z.getValueFor(e),s=Ce.getValueFor(e),t.get(t.closestIndexOf((0,I.C)(r))+s);var t,r,s}}),Le=(B("neutral-layer-card-container").withDefault((e=>Pe.getValueFor(e).evaluate(e))),E("neutral-layer-floating-recipe").withDefault({evaluate:e=>function(e,t,r){const s=e.closestIndexOf((0,I.C)(t))-r;return e.get(s-r)}(Se.getValueFor(e),z.getValueFor(e),Ce.getValueFor(e))})),Re=(B("neutral-layer-floating").withDefault((e=>Le.getValueFor(e).evaluate(e))),E("neutral-layer-1-recipe").withDefault({evaluate:e=>function(e,t){return e.get(e.closestIndexOf((0,I.C)(t)))}(Se.getValueFor(e),z.getValueFor(e))})),Ne=B("neutral-layer-1").withDefault((e=>Re.getValueFor(e).evaluate(e))),Me=E("neutral-layer-2-recipe").withDefault({evaluate:e=>{return t=Se.getValueFor(e),r=z.getValueFor(e),s=Ce.getValueFor(e),n=ie.getValueFor(e),i=oe.getValueFor(e),o=ae.getValueFor(e),t.get(j(t,r,s,n,i,o));var t,r,s,n,i,o}}),Ae=(B("neutral-layer-2").withDefault((e=>Me.getValueFor(e).evaluate(e))),E("neutral-layer-3-recipe").withDefault({evaluate:e=>{return t=Se.getValueFor(e),r=z.getValueFor(e),s=Ce.getValueFor(e),n=ie.getValueFor(e),i=oe.getValueFor(e),o=ae.getValueFor(e),t.get(j(t,r,s,n,i,o)+s);var t,r,s,n,i,o}})),Ie=(B("neutral-layer-3").withDefault((e=>Ae.getValueFor(e).evaluate(e))),E("neutral-layer-4-recipe").withDefault({evaluate:e=>{return t=Se.getValueFor(e),r=z.getValueFor(e),s=Ce.getValueFor(e),n=ie.getValueFor(e),i=oe.getValueFor(e),o=ae.getValueFor(e),t.get(j(t,r,s,n,i,o)+2*s);var t,r,s,n,i,o}})),je=(B("neutral-layer-4").withDefault((e=>Ie.getValueFor(e).evaluate(e))),B("fill-color").withDefault((e=>Ne.getValueFor(e))));var Be;!function(e){e[e.normal=4.5]="normal",e[e.large=7]="large"}(Be||(Be={}));const Ee=B({name:"accent-fill-recipe",cssCustomPropertyName:null}).withDefault({evaluate:(e,t)=>function(e,t,r,s,n,i,o,a,l){const u=e.source,h=t.closestIndexOf(r)>=Math.max(o,a,l)?-1:1,c=e.closestIndexOf(u),d=c+-1*h*s,g=d+h*n,f=d+h*i;return{rest:e.get(d),hover:e.get(c),active:e.get(g),focus:e.get(f)}}(Te.getValueFor(e),Se.getValueFor(e),t||je.getValueFor(e),K.getValueFor(e),J.getValueFor(e),ee.getValueFor(e),ie.getValueFor(e),oe.getValueFor(e),ae.getValueFor(e))}),_e=B("accent-fill-rest").withDefault((e=>Ee.getValueFor(e).evaluate(e).rest)),He=B("accent-fill-hover").withDefault((e=>Ee.getValueFor(e).evaluate(e).hover)),ze=B("accent-fill-active").withDefault((e=>Ee.getValueFor(e).evaluate(e).active)),qe=B("accent-fill-focus").withDefault((e=>Ee.getValueFor(e).evaluate(e).focus)),Ue=e=>(t,r)=>function(e,t){return e.contrast(L)>=t?L:R}(r||_e.getValueFor(t),e),We=E("foreground-on-accent-recipe").withDefault({evaluate:(e,t)=>Ue(Be.normal)(e,t)}),Ze=B("foreground-on-accent-rest").withDefault((e=>We.getValueFor(e).evaluate(e,_e.getValueFor(e)))),Ge=B("foreground-on-accent-hover").withDefault((e=>We.getValueFor(e).evaluate(e,He.getValueFor(e)))),Ye=B("foreground-on-accent-active").withDefault((e=>We.getValueFor(e).evaluate(e,ze.getValueFor(e)))),Xe=(B("foreground-on-accent-focus").withDefault((e=>We.getValueFor(e).evaluate(e,qe.getValueFor(e)))),E("foreground-on-accent-large-recipe").withDefault({evaluate:(e,t)=>Ue(Be.large)(e,t)})),Qe=(B("foreground-on-accent-rest-large").withDefault((e=>Xe.getValueFor(e).evaluate(e,_e.getValueFor(e)))),B("foreground-on-accent-hover-large").withDefault((e=>Xe.getValueFor(e).evaluate(e,He.getValueFor(e)))),B("foreground-on-accent-active-large").withDefault((e=>Xe.getValueFor(e).evaluate(e,ze.getValueFor(e)))),B("foreground-on-accent-focus-large").withDefault((e=>Xe.getValueFor(e).evaluate(e,qe.getValueFor(e)))),e=>(t,r)=>function(e,t,r,s,n,i,o){const a=e.source,l=e.closestIndexOf(a),u=S(t),h=l+(1===u?Math.min(s,n):Math.max(u*s,u*n)),c=e.colorContrast(t,r,h,u),d=e.closestIndexOf(c),g=d+u*Math.abs(s-n);let f,p;return(1===u?s<n:u*s>u*n)?(f=d,p=g):(f=g,p=d),{rest:e.get(f),hover:e.get(p),active:e.get(f+u*i),focus:e.get(f+u*o)}}(Te.getValueFor(t),r||je.getValueFor(t),e,te.getValueFor(t),re.getValueFor(t),se.getValueFor(t),ne.getValueFor(t))),Ke=B({name:"accent-foreground-recipe",cssCustomPropertyName:null}).withDefault({evaluate:(e,t)=>Qe(Be.normal)(e,t)}),Je=B("accent-foreground-rest").withDefault((e=>Ke.getValueFor(e).evaluate(e).rest)),et=B("accent-foreground-hover").withDefault((e=>Ke.getValueFor(e).evaluate(e).hover)),tt=B("accent-foreground-active").withDefault((e=>Ke.getValueFor(e).evaluate(e).active)),rt=(B("accent-foreground-focus").withDefault((e=>Ke.getValueFor(e).evaluate(e).focus)),B({name:"neutral-fill-recipe",cssCustomPropertyName:null}).withDefault({evaluate:(e,t)=>function(e,t,r,s,n,i){const o=e.closestIndexOf(t),a=o>=Math.max(r,s,n,i)?-1:1;return{rest:e.get(o+a*r),hover:e.get(o+a*s),active:e.get(o+a*n),focus:e.get(o+a*i)}}(Se.getValueFor(e),t||je.getValueFor(e),ie.getValueFor(e),oe.getValueFor(e),ae.getValueFor(e),le.getValueFor(e))})),st=B("neutral-fill-rest").withDefault((e=>rt.getValueFor(e).evaluate(e).rest)),nt=B("neutral-fill-hover").withDefault((e=>rt.getValueFor(e).evaluate(e).hover)),it=B("neutral-fill-active").withDefault((e=>rt.getValueFor(e).evaluate(e).active)),ot=(B("neutral-fill-focus").withDefault((e=>rt.getValueFor(e).evaluate(e).focus)),B({name:"neutral-fill-input-recipe",cssCustomPropertyName:null}).withDefault({evaluate:(e,t)=>function(e,t,r,s,n,i){const o=S(t),a=e.closestIndexOf(t);return{rest:e.get(a-o*r),hover:e.get(a-o*s),active:e.get(a-o*n),focus:e.get(a-o*i)}}(Se.getValueFor(e),t||je.getValueFor(e),ue.getValueFor(e),he.getValueFor(e),ce.getValueFor(e),de.getValueFor(e))})),at=B("neutral-fill-input-rest").withDefault((e=>ot.getValueFor(e).evaluate(e).rest)),lt=B("neutral-fill-input-hover").withDefault((e=>ot.getValueFor(e).evaluate(e).hover)),ut=(B("neutral-fill-input-active").withDefault((e=>ot.getValueFor(e).evaluate(e).active)),B("neutral-fill-input-focus").withDefault((e=>ot.getValueFor(e).evaluate(e).focus)),B({name:"neutral-fill-stealth-recipe",cssCustomPropertyName:null}).withDefault({evaluate:(e,t)=>function(e,t,r,s,n,i,o,a,l,u){const h=Math.max(r,s,n,i,o,a,l,u),c=e.closestIndexOf(t),d=c>=h?-1:1;return{rest:e.get(c+d*r),hover:e.get(c+d*s),active:e.get(c+d*n),focus:e.get(c+d*i)}}(Se.getValueFor(e),t||je.getValueFor(e),ge.getValueFor(e),fe.getValueFor(e),pe.getValueFor(e),be.getValueFor(e),ie.getValueFor(e),oe.getValueFor(e),ae.getValueFor(e),le.getValueFor(e))})),ht=(B("neutral-fill-stealth-rest").withDefault((e=>ut.getValueFor(e).evaluate(e).rest)),B("neutral-fill-stealth-hover").withDefault((e=>ut.getValueFor(e).evaluate(e).hover))),ct=B("neutral-fill-stealth-active").withDefault((e=>ut.getValueFor(e).evaluate(e).active)),dt=(B("neutral-fill-stealth-focus").withDefault((e=>ut.getValueFor(e).evaluate(e).focus)),B({name:"neutral-fill-strong-recipe",cssCustomPropertyName:null}).withDefault({evaluate:(e,t)=>function(e,t,r,s,n,i){const o=S(t),a=e.closestIndexOf(e.colorContrast(t,4.5)),l=a+o*Math.abs(r-s);let u,h;return(1===o?r<s:o*r>o*s)?(u=a,h=l):(u=l,h=a),{rest:e.get(u),hover:e.get(h),active:e.get(u+o*n),focus:e.get(u+o*i)}}(Se.getValueFor(e),t||je.getValueFor(e),ve.getValueFor(e),me.getValueFor(e),ye.getValueFor(e),we.getValueFor(e))})),gt=B("neutral-fill-strong-rest").withDefault((e=>dt.getValueFor(e).evaluate(e).rest)),ft=B("neutral-fill-strong-hover").withDefault((e=>dt.getValueFor(e).evaluate(e).hover)),pt=B("neutral-fill-strong-active").withDefault((e=>dt.getValueFor(e).evaluate(e).active)),bt=B("neutral-fill-strong-focus").withDefault((e=>dt.getValueFor(e).evaluate(e).focus)),vt=E("neutral-fill-layer-recipe").withDefault({evaluate:(e,t)=>function(e,t,r){const s=e.closestIndexOf(t);return e.get(s-(s<r?-1*r:r))}(Se.getValueFor(e),t||je.getValueFor(e),Ce.getValueFor(e))}),mt=(B("neutral-fill-layer-rest").withDefault((e=>vt.getValueFor(e).evaluate(e))),E("focus-stroke-outer-recipe").withDefault({evaluate:e=>{return t=Se.getValueFor(e),r=je.getValueFor(e),t.colorContrast(r,3.5);var t,r}})),yt=B("focus-stroke-outer").withDefault((e=>mt.getValueFor(e).evaluate(e))),wt=E("focus-stroke-inner-recipe").withDefault({evaluate:e=>{return t=Te.getValueFor(e),r=je.getValueFor(e),s=yt.getValueFor(e),t.colorContrast(s,3.5,t.closestIndexOf(t.source),-1*S(r));var t,r,s}}),Ct=(B("focus-stroke-inner").withDefault((e=>wt.getValueFor(e).evaluate(e))),E("neutral-foreground-hint-recipe").withDefault({evaluate:e=>{return t=Se.getValueFor(e),r=je.getValueFor(e),t.colorContrast(r,4.5);var t,r}})),xt=(B("neutral-foreground-hint").withDefault((e=>Ct.getValueFor(e).evaluate(e))),E("neutral-foreground-recipe").withDefault({evaluate:e=>{return t=Se.getValueFor(e),r=je.getValueFor(e),t.colorContrast(r,14);var t,r}})),Vt=B("neutral-foreground-rest").withDefault((e=>xt.getValueFor(e).evaluate(e))),Ft=B({name:"neutral-stroke-recipe",cssCustomPropertyName:null}).withDefault({evaluate:e=>function(e,t,r,s,n,i){const o=e.closestIndexOf(t),a=S(t),l=o+a*r,u=l+a*(s-r),h=l+a*(n-r),c=l+a*(i-r);return{rest:e.get(l),hover:e.get(u),active:e.get(h),focus:e.get(c)}}(Se.getValueFor(e),je.getValueFor(e),xe.getValueFor(e),Ve.getValueFor(e),Fe.getValueFor(e),Oe.getValueFor(e))}),Ot=B("neutral-stroke-rest").withDefault((e=>Ft.getValueFor(e).evaluate(e).rest)),Dt=(B("neutral-stroke-hover").withDefault((e=>Ft.getValueFor(e).evaluate(e).hover)),B("neutral-stroke-active").withDefault((e=>Ft.getValueFor(e).evaluate(e).active)),B("neutral-stroke-focus").withDefault((e=>Ft.getValueFor(e).evaluate(e).focus)),E("neutral-stroke-divider-recipe").withDefault({evaluate:(e,t)=>function(e,t,r){return e.get(e.closestIndexOf(t)+S(t)*r)}(Se.getValueFor(e),t||je.getValueFor(e),De.getValueFor(e))})),kt=(B("neutral-stroke-divider-rest").withDefault((e=>Dt.getValueFor(e).evaluate(e))),n.DesignToken.create({name:"height-number",cssCustomPropertyName:null}).withDefault((e=>(H.getValueFor(e)+U.getValueFor(e))*W.getValueFor(e))),B("error-color").withDefault(A)),St=E("error-palette").withDefault((e=>T.from(kt.getValueFor(e)))),$t=B({name:"error-fill-recipe",cssCustomPropertyName:null}).withDefault({evaluate:(e,t)=>function(e,t,r,s,n,i,o,a,l){const u=e.source,h=t.closestIndexOf(r)>=Math.max(o,a,l)?-1:1,c=e.closestIndexOf(u),d=c+-1*h*s,g=d+h*n,f=d+h*i;return{rest:e.get(d),hover:e.get(c),active:e.get(g),focus:e.get(f)}}(St.getValueFor(e),Se.getValueFor(e),t||je.getValueFor(e),K.getValueFor(e),J.getValueFor(e),ee.getValueFor(e),ie.getValueFor(e),oe.getValueFor(e),ae.getValueFor(e))}),Tt=B("error-fill-rest").withDefault((e=>$t.getValueFor(e).evaluate(e).rest)),Pt=B("error-fill-hover").withDefault((e=>$t.getValueFor(e).evaluate(e).hover)),Lt=B("error-fill-active").withDefault((e=>$t.getValueFor(e).evaluate(e).active)),Rt=B("error-fill-focus").withDefault((e=>$t.getValueFor(e).evaluate(e).focus)),Nt=e=>(t,r)=>function(e,t){return e.contrast(L)>=t?L:R}(r||Tt.getValueFor(t),e),Mt=B({name:"foreground-on-error-recipe",cssCustomPropertyName:null}).withDefault({evaluate:(e,t)=>Nt(Be.normal)(e,t)}),At=(B("foreground-on-error-rest").withDefault((e=>Mt.getValueFor(e).evaluate(e,Tt.getValueFor(e)))),B("foreground-on-error-hover").withDefault((e=>Mt.getValueFor(e).evaluate(e,Pt.getValueFor(e)))),B("foreground-on-error-active").withDefault((e=>Mt.getValueFor(e).evaluate(e,Lt.getValueFor(e)))),B("foreground-on-error-focus").withDefault((e=>Mt.getValueFor(e).evaluate(e,Rt.getValueFor(e)))),B({name:"foreground-on-error-large-recipe",cssCustomPropertyName:null}).withDefault({evaluate:(e,t)=>Nt(Be.large)(e,t)})),It=(B("foreground-on-error-rest-large").withDefault((e=>At.getValueFor(e).evaluate(e,Tt.getValueFor(e)))),B("foreground-on-error-hover-large").withDefault((e=>At.getValueFor(e).evaluate(e,Pt.getValueFor(e)))),B("foreground-on-error-active-large").withDefault((e=>At.getValueFor(e).evaluate(e,Lt.getValueFor(e)))),B("foreground-on-error-focus-large").withDefault((e=>At.getValueFor(e).evaluate(e,Rt.getValueFor(e)))),e=>(t,r)=>function(e,t,r,s,n,i,o){const a=e.source,l=e.closestIndexOf(a),u=(0,k._)(t)?-1:1,h=l+(1===u?Math.min(s,n):Math.max(u*s,u*n)),c=e.colorContrast(t,r,h,u),d=e.closestIndexOf(c),g=d+u*Math.abs(s-n);let f,p;return(1===u?s<n:u*s>u*n)?(f=d,p=g):(f=g,p=d),{rest:e.get(f),hover:e.get(p),active:e.get(f+u*i),focus:e.get(f+u*o)}}(St.getValueFor(t),r||je.getValueFor(t),e,te.getValueFor(t),re.getValueFor(t),se.getValueFor(t),ne.getValueFor(t))),jt=B({name:"error-foreground-recipe",cssCustomPropertyName:null}).withDefault({evaluate:(e,t)=>It(Be.normal)(e,t)}),Bt=(B("error-foreground-rest").withDefault((e=>jt.getValueFor(e).evaluate(e).rest)),B("error-foreground-hover").withDefault((e=>jt.getValueFor(e).evaluate(e).hover)),B("error-foreground-active").withDefault((e=>jt.getValueFor(e).evaluate(e).active)));B("error-foreground-focus").withDefault((e=>jt.getValueFor(e).evaluate(e).focus))},68866:(e,t,r)=>{r.d(t,{W:()=>b});var s=r(74855),n=r(50755),i=r(70529),o=r(27002),a=r(40791);const l=Object.freeze({definitionCallbackOnly:null,ignoreDuplicate:Symbol()}),u=new Map,h=new Map;let c=null;const d=i.DI.createInterface((e=>e.cachedCallback((e=>(null===c&&(c=new f(null,e)),c))))),g=Object.freeze({tagFor:e=>h.get(e),responsibleFor(e){const t=e.$$designSystem$$;return t||i.DI.findResponsibleContainer(e).get(d)},getOrCreate(e){if(!e)return null===c&&(c=i.DI.getOrCreateDOMContainer().get(d)),c;const t=e.$$designSystem$$;if(t)return t;const r=i.DI.getOrCreateDOMContainer(e);if(r.has(d,!1))return r.get(d);{const t=new f(e,r);return r.register(i.YM.instance(d,t)),t}}});class f{constructor(e,t){this.owner=e,this.container=t,this.designTokensInitialized=!1,this.prefix="fast",this.shadowRootMode=void 0,this.disambiguate=()=>l.definitionCallbackOnly,null!==e&&(e.$$designSystem$$=this)}withPrefix(e){return this.prefix=e,this}withShadowRootMode(e){return this.shadowRootMode=e,this}withElementDisambiguation(e){return this.disambiguate=e,this}withDesignTokenRoot(e){return this.designTokenRoot=e,this}register(...e){const t=this.container,r=[],s=this.disambiguate,i=this.shadowRootMode,a={elementPrefix:this.prefix,tryDefineElement(e,o,a){const c=function(e,t,r){return"string"==typeof e?{name:e,type:t,callback:r}:e}(e,o,a),{name:d,callback:g,baseClass:f}=c;let{type:b}=c,v=d,m=u.get(v),y=!0;for(;m;){const e=s(v,b,m);switch(e){case l.ignoreDuplicate:return;case l.definitionCallbackOnly:y=!1,m=void 0;break;default:v=e,m=u.get(v)}}y&&((h.has(b)||b===n.I)&&(b=class extends b{}),u.set(v,b),h.set(b,v),f&&h.set(f,v)),r.push(new p(t,v,b,i,g,y))}};this.designTokensInitialized||(this.designTokensInitialized=!0,null!==this.designTokenRoot&&o.DesignToken.registerRoot(this.designTokenRoot)),t.registerWithContext(a,...e);for(const e of r)e.callback(e),e.willDefine&&null!==e.definition&&e.definition.define();return this}}class p{constructor(e,t,r,s,n,i){this.container=e,this.name=t,this.type=r,this.shadowRootMode=s,this.callback=n,this.willDefine=i,this.definition=null}definePresentation(e){a.v.define(this.name,e,this.container)}defineElement(e){this.definition=new s.W(this.type,Object.assign(Object.assign({},e),{name:this.name}))}tagFor(e){return g.tagFor(e)}}function b(e){return g.getOrCreate(e).withPrefix("jp")}},13370:(e,t,r)=>{r.d(t,{i:()=>i});var s=r(12634),n=r(87206);const i=s.j`(${n.nf} + ${n.hV}) * ${n._5}`},76962:(e,t,r)=>{r.d(t,{$2:()=>x,DR:()=>C,KW:()=>V,T8:()=>b,hM:()=>c,hP:()=>p,iI:()=>v,lw:()=>f,rD:()=>y,rp:()=>h,v1:()=>w,wo:()=>g,zP:()=>m});var s=r(77727),n=r(25700),i=r(70656),o=r(29087),a=r(616),l=r(82800),u=r(58902);function h(e){return.2126*e.r+.7152*e.g+.0722*e.b}function c(e){function t(e){return e<=.03928?e/12.92:Math.pow((e+.055)/1.055,2.4)}return h(new a.h(t(e.r),t(e.g),t(e.b),1))}const d=(e,t)=>(e+.05)/(t+.05);function g(e,t){const r=c(e),s=c(t);return r>s?d(r,s):d(s,r)}function f(e){const t=Math.max(e.r,e.g,e.b),r=Math.min(e.r,e.g,e.b),n=t-r;let i=0;0!==n&&(i=t===e.r?(e.g-e.b)/n%6*60:t===e.g?60*((e.b-e.r)/n+2):60*((e.r-e.g)/n+4)),i<0&&(i+=360);const o=(t+r)/2;let a=0;return 0!==n&&(a=n/(1-Math.abs(2*o-1))),new s.H(i,a,o)}function p(e,t=1){const r=(1-Math.abs(2*e.l-1))*e.s,s=r*(1-Math.abs(e.h/60%2-1)),n=e.l-r/2;let i=0,o=0,l=0;return e.h<60?(i=r,o=s,l=0):e.h<120?(i=s,o=r,l=0):e.h<180?(i=0,o=r,l=s):e.h<240?(i=0,o=s,l=r):e.h<300?(i=s,o=0,l=r):e.h<360&&(i=r,o=0,l=s),new a.h(i+n,o+n,l+n,t)}function b(e){const t=Math.max(e.r,e.g,e.b),r=t-Math.min(e.r,e.g,e.b);let s=0;0!==r&&(s=t===e.r?(e.g-e.b)/r%6*60:t===e.g?60*((e.b-e.r)/r+2):60*((e.r-e.g)/r+4)),s<0&&(s+=360);let i=0;return 0!==t&&(i=r/t),new n.T(s,i,t)}function v(e,t=1){const r=e.s*e.v,s=r*(1-Math.abs(e.h/60%2-1)),n=e.v-r;let i=0,o=0,l=0;return e.h<60?(i=r,o=s,l=0):e.h<120?(i=s,o=r,l=0):e.h<180?(i=0,o=r,l=s):e.h<240?(i=0,o=s,l=r):e.h<300?(i=s,o=0,l=r):e.h<360&&(i=r,o=0,l=s),new a.h(i+n,o+n,l+n,t)}function m(e){function t(e){return e<=.04045?e/12.92:Math.pow((e+.055)/1.055,2.4)}const r=t(e.r),s=t(e.g),n=t(e.b),i=.4124564*r+.3575761*s+.1804375*n,o=.2126729*r+.7151522*s+.072175*n,a=.0193339*r+.119192*s+.9503041*n;return new l.x(i,o,a)}function y(e,t=1){function r(e){return e<=.0031308?12.92*e:1.055*Math.pow(e,1/2.4)-.055}const s=r(3.2404542*e.x-1.5371385*e.y-.4985314*e.z),n=r(-.969266*e.x+1.8760108*e.y+.041556*e.z),i=r(.0556434*e.x-.2040259*e.y+1.0572252*e.z);return new a.h(s,n,i,t)}function w(e){return function(e){function t(e){return e>i.R.epsilon?Math.pow(e,1/3):(i.R.kappa*e+16)/116}const r=t(e.x/l.x.whitePoint.x),s=t(e.y/l.x.whitePoint.y),n=116*s-16,o=500*(r-s),a=200*(s-t(e.z/l.x.whitePoint.z));return new i.R(n,o,a)}(m(e))}function C(e,t=1){return y(function(e){const t=(e.l+16)/116,r=t+e.a/500,s=t-e.b/200,n=Math.pow(r,3),o=Math.pow(t,3),a=Math.pow(s,3);let u=0;u=n>i.R.epsilon?n:(116*r-16)/i.R.kappa;let h=0;h=e.l>i.R.epsilon*i.R.kappa?o:e.l/i.R.kappa;let c=0;return c=a>i.R.epsilon?a:(116*s-16)/i.R.kappa,u=l.x.whitePoint.x*u,h=l.x.whitePoint.y*h,c=l.x.whitePoint.z*c,new l.x(u,h,c)}(e),t)}function x(e){return function(e){let t=0;(Math.abs(e.b)>.001||Math.abs(e.a)>.001)&&(t=(0,u.vi)(Math.atan2(e.b,e.a))),t<0&&(t+=360);const r=Math.sqrt(e.a*e.a+e.b*e.b);return new o.t(e.l,r,t)}(w(e))}function V(e,t=1){return C(function(e){let t=0,r=0;return 0!==e.h&&(t=Math.cos((0,u.Ht)(e.h))*e.c,r=Math.sin((0,u.Ht)(e.h))*e.c),new i.R(e.l,t,r)}(e),t)}},77727:(e,t,r)=>{r.d(t,{H:()=>n});var s=r(58902);class n{constructor(e,t,r){this.h=e,this.s=t,this.l=r}static fromObject(e){return!e||isNaN(e.h)||isNaN(e.s)||isNaN(e.l)?null:new n(e.h,e.s,e.l)}equalValue(e){return this.h===e.h&&this.s===e.s&&this.l===e.l}roundToPrecision(e){return new n((0,s.fZ)(this.h,e),(0,s.fZ)(this.s,e),(0,s.fZ)(this.l,e))}toObject(){return{h:this.h,s:this.s,l:this.l}}}},25700:(e,t,r)=>{r.d(t,{T:()=>n});var s=r(58902);class n{constructor(e,t,r){this.h=e,this.s=t,this.v=r}static fromObject(e){return!e||isNaN(e.h)||isNaN(e.s)||isNaN(e.v)?null:new n(e.h,e.s,e.v)}equalValue(e){return this.h===e.h&&this.s===e.s&&this.v===e.v}roundToPrecision(e){return new n((0,s.fZ)(this.h,e),(0,s.fZ)(this.s,e),(0,s.fZ)(this.v,e))}toObject(){return{h:this.h,s:this.s,v:this.v}}}},70656:(e,t,r)=>{r.d(t,{R:()=>n});var s=r(58902);class n{constructor(e,t,r){this.l=e,this.a=t,this.b=r}static fromObject(e){return!e||isNaN(e.l)||isNaN(e.a)||isNaN(e.b)?null:new n(e.l,e.a,e.b)}equalValue(e){return this.l===e.l&&this.a===e.a&&this.b===e.b}roundToPrecision(e){return new n((0,s.fZ)(this.l,e),(0,s.fZ)(this.a,e),(0,s.fZ)(this.b,e))}toObject(){return{l:this.l,a:this.a,b:this.b}}}n.epsilon=216/24389,n.kappa=24389/27},29087:(e,t,r)=>{r.d(t,{t:()=>n});var s=r(58902);class n{constructor(e,t,r){this.l=e,this.c=t,this.h=r}static fromObject(e){return!e||isNaN(e.l)||isNaN(e.c)||isNaN(e.h)?null:new n(e.l,e.c,e.h)}equalValue(e){return this.l===e.l&&this.c===e.c&&this.h===e.h}roundToPrecision(e){return new n((0,s.fZ)(this.l,e),(0,s.fZ)(this.c,e),(0,s.fZ)(this.h,e))}toObject(){return{l:this.l,c:this.c,h:this.h}}}},616:(e,t,r)=>{r.d(t,{h:()=>n});var s=r(58902);class n{constructor(e,t,r,s){this.r=e,this.g=t,this.b=r,this.a="number"!=typeof s||isNaN(s)?1:s}static fromObject(e){return!e||isNaN(e.r)||isNaN(e.g)||isNaN(e.b)?null:new n(e.r,e.g,e.b,e.a)}equalValue(e){return this.r===e.r&&this.g===e.g&&this.b===e.b&&this.a===e.a}toStringHexRGB(){return"#"+[this.r,this.g,this.b].map(this.formatHexValue).join("")}toStringHexRGBA(){return this.toStringHexRGB()+this.formatHexValue(this.a)}toStringHexARGB(){return"#"+[this.a,this.r,this.g,this.b].map(this.formatHexValue).join("")}toStringWebRGB(){return`rgb(${Math.round((0,s.cY)(this.r,0,255))},${Math.round((0,s.cY)(this.g,0,255))},${Math.round((0,s.cY)(this.b,0,255))})`}toStringWebRGBA(){return`rgba(${Math.round((0,s.cY)(this.r,0,255))},${Math.round((0,s.cY)(this.g,0,255))},${Math.round((0,s.cY)(this.b,0,255))},${(0,s.uZ)(this.a,0,1)})`}roundToPrecision(e){return new n((0,s.fZ)(this.r,e),(0,s.fZ)(this.g,e),(0,s.fZ)(this.b,e),(0,s.fZ)(this.a,e))}clamp(){return new n((0,s.uZ)(this.r,0,1),(0,s.uZ)(this.g,0,1),(0,s.uZ)(this.b,0,1),(0,s.uZ)(this.a,0,1))}toObject(){return{r:this.r,g:this.g,b:this.b,a:this.a}}formatHexValue(e){return(0,s.yi)((0,s.cY)(e,0,255))}}},82800:(e,t,r)=>{r.d(t,{x:()=>n});var s=r(58902);class n{constructor(e,t,r){this.x=e,this.y=t,this.z=r}static fromObject(e){return!e||isNaN(e.x)||isNaN(e.y)||isNaN(e.z)?null:new n(e.x,e.y,e.z)}equalValue(e){return this.x===e.x&&this.y===e.y&&this.z===e.z}roundToPrecision(e){return new n((0,s.fZ)(this.x,e),(0,s.fZ)(this.y,e),(0,s.fZ)(this.z,e))}toObject(){return{x:this.x,y:this.y,z:this.z}}}n.whitePoint=new n(.95047,1,1.08883)},58902:(e,t,r)=>{function s(e,t,r){return isNaN(e)||e<=t?t:e>=r?r:e}function n(e,t,r){return isNaN(e)||e<=t?0:e>=r?1:e/(r-t)}function i(e,t,r){return isNaN(e)?t:t+e*(r-t)}function o(e){return e*(Math.PI/180)}function a(e){return e*(180/Math.PI)}function l(e){const t=Math.round(s(e,0,255)).toString(16);return 1===t.length?"0"+t:t}function u(e,t,r){return isNaN(e)||e<=0?t:e>=1?r:t+e*(r-t)}function h(e,t,r){if(e<=0)return t%360;if(e>=1)return r%360;const s=(t-r+360)%360;return s<=(r-t+360)%360?(t-s*e+360)%360:(t+s*e+360)%360}function c(e,t){const r=Math.pow(10,t);return Math.round(e*r)/r}r.d(t,{AG:()=>h,Fv:()=>n,Ht:()=>o,cY:()=>i,fZ:()=>c,t7:()=>u,uZ:()=>s,vi:()=>a,yi:()=>l}),Math.PI},93484:(e,t,r)=>{r.d(t,{lu:()=>c,in:()=>h});var s=r(616),n=r(58902);const i={aliceblue:{r:.941176,g:.972549,b:1},antiquewhite:{r:.980392,g:.921569,b:.843137},aqua:{r:0,g:1,b:1},aquamarine:{r:.498039,g:1,b:.831373},azure:{r:.941176,g:1,b:1},beige:{r:.960784,g:.960784,b:.862745},bisque:{r:1,g:.894118,b:.768627},black:{r:0,g:0,b:0},blanchedalmond:{r:1,g:.921569,b:.803922},blue:{r:0,g:0,b:1},blueviolet:{r:.541176,g:.168627,b:.886275},brown:{r:.647059,g:.164706,b:.164706},burlywood:{r:.870588,g:.721569,b:.529412},cadetblue:{r:.372549,g:.619608,b:.627451},chartreuse:{r:.498039,g:1,b:0},chocolate:{r:.823529,g:.411765,b:.117647},coral:{r:1,g:.498039,b:.313725},cornflowerblue:{r:.392157,g:.584314,b:.929412},cornsilk:{r:1,g:.972549,b:.862745},crimson:{r:.862745,g:.078431,b:.235294},cyan:{r:0,g:1,b:1},darkblue:{r:0,g:0,b:.545098},darkcyan:{r:0,g:.545098,b:.545098},darkgoldenrod:{r:.721569,g:.52549,b:.043137},darkgray:{r:.662745,g:.662745,b:.662745},darkgreen:{r:0,g:.392157,b:0},darkgrey:{r:.662745,g:.662745,b:.662745},darkkhaki:{r:.741176,g:.717647,b:.419608},darkmagenta:{r:.545098,g:0,b:.545098},darkolivegreen:{r:.333333,g:.419608,b:.184314},darkorange:{r:1,g:.54902,b:0},darkorchid:{r:.6,g:.196078,b:.8},darkred:{r:.545098,g:0,b:0},darksalmon:{r:.913725,g:.588235,b:.478431},darkseagreen:{r:.560784,g:.737255,b:.560784},darkslateblue:{r:.282353,g:.239216,b:.545098},darkslategray:{r:.184314,g:.309804,b:.309804},darkslategrey:{r:.184314,g:.309804,b:.309804},darkturquoise:{r:0,g:.807843,b:.819608},darkviolet:{r:.580392,g:0,b:.827451},deeppink:{r:1,g:.078431,b:.576471},deepskyblue:{r:0,g:.74902,b:1},dimgray:{r:.411765,g:.411765,b:.411765},dimgrey:{r:.411765,g:.411765,b:.411765},dodgerblue:{r:.117647,g:.564706,b:1},firebrick:{r:.698039,g:.133333,b:.133333},floralwhite:{r:1,g:.980392,b:.941176},forestgreen:{r:.133333,g:.545098,b:.133333},fuchsia:{r:1,g:0,b:1},gainsboro:{r:.862745,g:.862745,b:.862745},ghostwhite:{r:.972549,g:.972549,b:1},gold:{r:1,g:.843137,b:0},goldenrod:{r:.854902,g:.647059,b:.12549},gray:{r:.501961,g:.501961,b:.501961},green:{r:0,g:.501961,b:0},greenyellow:{r:.678431,g:1,b:.184314},grey:{r:.501961,g:.501961,b:.501961},honeydew:{r:.941176,g:1,b:.941176},hotpink:{r:1,g:.411765,b:.705882},indianred:{r:.803922,g:.360784,b:.360784},indigo:{r:.294118,g:0,b:.509804},ivory:{r:1,g:1,b:.941176},khaki:{r:.941176,g:.901961,b:.54902},lavender:{r:.901961,g:.901961,b:.980392},lavenderblush:{r:1,g:.941176,b:.960784},lawngreen:{r:.486275,g:.988235,b:0},lemonchiffon:{r:1,g:.980392,b:.803922},lightblue:{r:.678431,g:.847059,b:.901961},lightcoral:{r:.941176,g:.501961,b:.501961},lightcyan:{r:.878431,g:1,b:1},lightgoldenrodyellow:{r:.980392,g:.980392,b:.823529},lightgray:{r:.827451,g:.827451,b:.827451},lightgreen:{r:.564706,g:.933333,b:.564706},lightgrey:{r:.827451,g:.827451,b:.827451},lightpink:{r:1,g:.713725,b:.756863},lightsalmon:{r:1,g:.627451,b:.478431},lightseagreen:{r:.12549,g:.698039,b:.666667},lightskyblue:{r:.529412,g:.807843,b:.980392},lightslategray:{r:.466667,g:.533333,b:.6},lightslategrey:{r:.466667,g:.533333,b:.6},lightsteelblue:{r:.690196,g:.768627,b:.870588},lightyellow:{r:1,g:1,b:.878431},lime:{r:0,g:1,b:0},limegreen:{r:.196078,g:.803922,b:.196078},linen:{r:.980392,g:.941176,b:.901961},magenta:{r:1,g:0,b:1},maroon:{r:.501961,g:0,b:0},mediumaquamarine:{r:.4,g:.803922,b:.666667},mediumblue:{r:0,g:0,b:.803922},mediumorchid:{r:.729412,g:.333333,b:.827451},mediumpurple:{r:.576471,g:.439216,b:.858824},mediumseagreen:{r:.235294,g:.701961,b:.443137},mediumslateblue:{r:.482353,g:.407843,b:.933333},mediumspringgreen:{r:0,g:.980392,b:.603922},mediumturquoise:{r:.282353,g:.819608,b:.8},mediumvioletred:{r:.780392,g:.082353,b:.521569},midnightblue:{r:.098039,g:.098039,b:.439216},mintcream:{r:.960784,g:1,b:.980392},mistyrose:{r:1,g:.894118,b:.882353},moccasin:{r:1,g:.894118,b:.709804},navajowhite:{r:1,g:.870588,b:.678431},navy:{r:0,g:0,b:.501961},oldlace:{r:.992157,g:.960784,b:.901961},olive:{r:.501961,g:.501961,b:0},olivedrab:{r:.419608,g:.556863,b:.137255},orange:{r:1,g:.647059,b:0},orangered:{r:1,g:.270588,b:0},orchid:{r:.854902,g:.439216,b:.839216},palegoldenrod:{r:.933333,g:.909804,b:.666667},palegreen:{r:.596078,g:.984314,b:.596078},paleturquoise:{r:.686275,g:.933333,b:.933333},palevioletred:{r:.858824,g:.439216,b:.576471},papayawhip:{r:1,g:.937255,b:.835294},peachpuff:{r:1,g:.854902,b:.72549},peru:{r:.803922,g:.521569,b:.247059},pink:{r:1,g:.752941,b:.796078},plum:{r:.866667,g:.627451,b:.866667},powderblue:{r:.690196,g:.878431,b:.901961},purple:{r:.501961,g:0,b:.501961},red:{r:1,g:0,b:0},rosybrown:{r:.737255,g:.560784,b:.560784},royalblue:{r:.254902,g:.411765,b:.882353},saddlebrown:{r:.545098,g:.270588,b:.07451},salmon:{r:.980392,g:.501961,b:.447059},sandybrown:{r:.956863,g:.643137,b:.376471},seagreen:{r:.180392,g:.545098,b:.341176},seashell:{r:1,g:.960784,b:.933333},sienna:{r:.627451,g:.321569,b:.176471},silver:{r:.752941,g:.752941,b:.752941},skyblue:{r:.529412,g:.807843,b:.921569},slateblue:{r:.415686,g:.352941,b:.803922},slategray:{r:.439216,g:.501961,b:.564706},slategrey:{r:.439216,g:.501961,b:.564706},snow:{r:1,g:.980392,b:.980392},springgreen:{r:0,g:1,b:.498039},steelblue:{r:.27451,g:.509804,b:.705882},tan:{r:.823529,g:.705882,b:.54902},teal:{r:0,g:.501961,b:.501961},thistle:{r:.847059,g:.74902,b:.847059},tomato:{r:1,g:.388235,b:.278431},transparent:{r:0,g:0,b:0,a:0},turquoise:{r:.25098,g:.878431,b:.815686},violet:{r:.933333,g:.509804,b:.933333},wheat:{r:.960784,g:.870588,b:.701961},white:{r:1,g:1,b:1},whitesmoke:{r:.960784,g:.960784,b:.960784},yellow:{r:1,g:1,b:0},yellowgreen:{r:.603922,g:.803922,b:.196078}},o=/^rgb\(\s*((?:(?:25[0-5]|2[0-4]\d|1\d\d|\d{1,2})\s*,\s*){2}(?:25[0-5]|2[0-4]\d|1\d\d|\d{1,2})\s*)\)$/i,a=/^rgba\(\s*((?:(?:25[0-5]|2[0-4]\d|1\d\d|\d{1,2})\s*,\s*){3}(?:0|1|0?\.\d*)\s*)\)$/i,l=/^#((?:[0-9a-f]{6}|[0-9a-f]{3}))$/i,u=/^#((?:[0-9a-f]{8}|[0-9a-f]{4}))$/i;function h(e){const t=l.exec(e);if(null===t)return null;let r=t[1];if(3===r.length){const e=r.charAt(0),t=r.charAt(1),s=r.charAt(2);r=e.concat(e,t,t,s,s)}const i=parseInt(r,16);return isNaN(i)?null:new s.h((0,n.Fv)((16711680&i)>>>16,0,255),(0,n.Fv)((65280&i)>>>8,0,255),(0,n.Fv)(255&i,0,255),1)}function c(e){const t=e.toLowerCase();return function(e){return l.test(e)}(t)?h(t):function(e){return function(e){return u.test(e)}(e)}(t)?function(e){const t=u.exec(e);if(null===t)return null;let r=t[1];if(4===r.length){const e=r.charAt(0),t=r.charAt(1),s=r.charAt(2),n=r.charAt(3);r=e.concat(e,t,t,s,s,n,n)}const i=parseInt(r,16);return isNaN(i)?null:new s.h((0,n.Fv)((16711680&i)>>>16,0,255),(0,n.Fv)((65280&i)>>>8,0,255),(0,n.Fv)(255&i,0,255),(0,n.Fv)((4278190080&i)>>>24,0,255))}(t):function(e){return o.test(e)}(t)?function(e){const t=o.exec(e);if(null===t)return null;const r=t[1].split(",");return new s.h((0,n.Fv)(Number(r[0]),0,255),(0,n.Fv)(Number(r[1]),0,255),(0,n.Fv)(Number(r[2]),0,255),1)}(t):function(e){return a.test(e)}(t)?function(e){const t=a.exec(e);if(null===t)return null;const r=t[1].split(",");return 4===r.length?new s.h((0,n.Fv)(Number(r[0]),0,255),(0,n.Fv)(Number(r[1]),0,255),(0,n.Fv)(Number(r[2]),0,255),Number(r[3])):null}(t):function(e){return i.hasOwnProperty(e)}(t)?function(e){const t=i[e.toLowerCase()];return t?new s.h(t.r,t.g,t.b,t.hasOwnProperty("a")?t.a:void 0):null}(t):null}},98332:(e,t,r)=>{r.d(t,{Ax:()=>o,Id:()=>l,Lj:()=>h,so:()=>u});var s=r(92221),n=r(91211),i=r(40478);const o=Object.freeze({locate:(0,i.j8)()}),a={toView:e=>e?"true":"false",fromView:e=>null!=e&&"false"!==e&&!1!==e&&0!==e},l={toView(e){if(null==e)return null;const t=1*e;return isNaN(t)?null:t.toString()},fromView(e){if(null==e)return null;const t=1*e;return isNaN(t)?null:t}};class u{constructor(e,t,r=t.toLowerCase(),s="reflect",n){this.guards=new Set,this.Owner=e,this.name=t,this.attribute=r,this.mode=s,this.converter=n,this.fieldName=`_${t}`,this.callbackName=`${t}Changed`,this.hasCallback=this.callbackName in e.prototype,"boolean"===s&&void 0===n&&(this.converter=a)}setValue(e,t){const r=e[this.fieldName],s=this.converter;void 0!==s&&(t=s.fromView(t)),r!==t&&(e[this.fieldName]=t,this.tryReflectToAttribute(e),this.hasCallback&&e[this.callbackName](r,t),e.$fastController.notify(this.name))}getValue(e){return s.y$.track(e,this.name),e[this.fieldName]}onAttributeChangedCallback(e,t){this.guards.has(e)||(this.guards.add(e),this.setValue(e,t),this.guards.delete(e))}tryReflectToAttribute(e){const t=this.mode,r=this.guards;r.has(e)||"fromView"===t||n.SO.queueUpdate((()=>{r.add(e);const s=e[this.fieldName];switch(t){case"reflect":const t=this.converter;n.SO.setAttribute(e,this.attribute,void 0!==t?t.toView(s):s);break;case"boolean":n.SO.setBooleanAttribute(e,this.attribute,s)}r.delete(e)}))}static collect(e,...t){const r=[];t.push(o.locate(e));for(let s=0,n=t.length;s<n;++s){const n=t[s];if(void 0!==n)for(let t=0,s=n.length;t<s;++t){const s=n[t];"string"==typeof s?r.push(new u(e,s)):r.push(new u(e,s.property,s.attribute,s.mode,s.converter))}}return r}}function h(e,t){let r;function s(e,t){arguments.length>1&&(r.property=t),o.locate(e.constructor).push(r)}return arguments.length>1?(r={},void s(e,t)):(r=void 0===e?{}:e,s)}},74855:(e,t,r)=>{r.d(t,{W:()=>h});var s=r(40478),n=r(92221),i=r(60956),o=r(98332);const a={mode:"open"},l={},u=s.Bo.getById(4,(()=>{const e=new Map;return Object.freeze({register:t=>!e.has(t.type)&&(e.set(t.type,t),!0),getByType:t=>e.get(t)})}));class h{constructor(e,t=e.definition){"string"==typeof t&&(t={name:t}),this.type=e,this.name=t.name,this.template=t.template;const r=o.so.collect(e,t.attributes),s=new Array(r.length),n={},u={};for(let e=0,t=r.length;e<t;++e){const t=r[e];s[e]=t.attribute,n[t.name]=t,u[t.attribute]=t}this.attributes=r,this.observedAttributes=s,this.propertyLookup=n,this.attributeLookup=u,this.shadowOptions=void 0===t.shadowOptions?a:null===t.shadowOptions?void 0:Object.assign(Object.assign({},a),t.shadowOptions),this.elementOptions=void 0===t.elementOptions?l:Object.assign(Object.assign({},l),t.elementOptions),this.styles=void 0===t.styles?void 0:Array.isArray(t.styles)?i.XL.create(t.styles):t.styles instanceof i.XL?t.styles:i.XL.create([t.styles])}get isDefined(){return!!u.getByType(this.type)}define(e=customElements){const t=this.type;if(u.register(this)){const e=this.attributes,r=t.prototype;for(let t=0,s=e.length;t<s;++t)n.y$.defineProperty(r,e[t]);Reflect.defineProperty(t,"observedAttributes",{value:this.observedAttributes,enumerable:!0})}return e.get(this.name)||e.define(this.name,t,this.elementOptions),this}}h.forType=u.getByType},58930:(e,t,r)=>{r.d(t,{H:()=>d});var s=r(91211),n=r(8111),i=r(92221),o=r(74855);const a=new WeakMap,l={bubbles:!0,composed:!0,cancelable:!0};function u(e){return e.shadowRoot||a.get(e)||null}class h extends n.A{constructor(e,t){super(e),this.boundObservables=null,this.behaviors=null,this.needsInitialization=!0,this._template=null,this._styles=null,this._isConnected=!1,this.$fastController=this,this.view=null,this.element=e,this.definition=t;const r=t.shadowOptions;if(void 0!==r){const t=e.attachShadow(r);"closed"===r.mode&&a.set(e,t)}const s=i.y$.getAccessors(e);if(s.length>0){const t=this.boundObservables=Object.create(null);for(let r=0,n=s.length;r<n;++r){const n=s[r].name,i=e[n];void 0!==i&&(delete e[n],t[n]=i)}}}get isConnected(){return i.y$.track(this,"isConnected"),this._isConnected}setIsConnected(e){this._isConnected=e,i.y$.notify(this,"isConnected")}get template(){return this._template}set template(e){this._template!==e&&(this._template=e,this.needsInitialization||this.renderTemplate(e))}get styles(){return this._styles}set styles(e){this._styles!==e&&(null!==this._styles&&this.removeStyles(this._styles),this._styles=e,this.needsInitialization||null===e||this.addStyles(e))}addStyles(e){const t=u(this.element)||this.element.getRootNode();if(e instanceof HTMLStyleElement)t.append(e);else if(!e.isAttachedTo(t)){const r=e.behaviors;e.addStylesTo(t),null!==r&&this.addBehaviors(r)}}removeStyles(e){const t=u(this.element)||this.element.getRootNode();if(e instanceof HTMLStyleElement)t.removeChild(e);else if(e.isAttachedTo(t)){const r=e.behaviors;e.removeStylesFrom(t),null!==r&&this.removeBehaviors(r)}}addBehaviors(e){const t=this.behaviors||(this.behaviors=new Map),r=e.length,s=[];for(let n=0;n<r;++n){const r=e[n];t.has(r)?t.set(r,t.get(r)+1):(t.set(r,1),s.push(r))}if(this._isConnected){const e=this.element;for(let t=0;t<s.length;++t)s[t].bind(e,i.Wp)}}removeBehaviors(e,t=!1){const r=this.behaviors;if(null===r)return;const s=e.length,n=[];for(let i=0;i<s;++i){const s=e[i];if(r.has(s)){const e=r.get(s)-1;0===e||t?r.delete(s)&&n.push(s):r.set(s,e)}}if(this._isConnected){const e=this.element;for(let t=0;t<n.length;++t)n[t].unbind(e)}}onConnectedCallback(){if(this._isConnected)return;const e=this.element;this.needsInitialization?this.finishInitialization():null!==this.view&&this.view.bind(e,i.Wp);const t=this.behaviors;if(null!==t)for(const[r]of t)r.bind(e,i.Wp);this.setIsConnected(!0)}onDisconnectedCallback(){if(!this._isConnected)return;this.setIsConnected(!1);const e=this.view;null!==e&&e.unbind();const t=this.behaviors;if(null!==t){const e=this.element;for(const[r]of t)r.unbind(e)}}onAttributeChangedCallback(e,t,r){const s=this.definition.attributeLookup[e];void 0!==s&&s.onAttributeChangedCallback(this.element,r)}emit(e,t,r){return!!this._isConnected&&this.element.dispatchEvent(new CustomEvent(e,Object.assign(Object.assign({detail:t},l),r)))}finishInitialization(){const e=this.element,t=this.boundObservables;if(null!==t){const r=Object.keys(t);for(let s=0,n=r.length;s<n;++s){const n=r[s];e[n]=t[n]}this.boundObservables=null}const r=this.definition;null===this._template&&(this.element.resolveTemplate?this._template=this.element.resolveTemplate():r.template&&(this._template=r.template||null)),null!==this._template&&this.renderTemplate(this._template),null===this._styles&&(this.element.resolveStyles?this._styles=this.element.resolveStyles():r.styles&&(this._styles=r.styles||null)),null!==this._styles&&this.addStyles(this._styles),this.needsInitialization=!1}renderTemplate(e){const t=this.element,r=u(t)||t;null!==this.view?(this.view.dispose(),this.view=null):this.needsInitialization||s.SO.removeChildNodes(r),e&&(this.view=e.render(t,r,t))}static forCustomElement(e){const t=e.$fastController;if(void 0!==t)return t;const r=o.W.forType(e.constructor);if(void 0===r)throw new Error("Missing FASTElement definition.");return e.$fastController=new h(e,r)}}function c(e){return class extends e{constructor(){super(),h.forCustomElement(this)}$emit(e,t,r){return this.$fastController.emit(e,t,r)}connectedCallback(){this.$fastController.onConnectedCallback()}disconnectedCallback(){this.$fastController.onDisconnectedCallback()}attributeChangedCallback(e,t,r){this.$fastController.onAttributeChangedCallback(e,t,r)}}}const d=Object.assign(c(HTMLElement),{from:e=>c(e),define:(e,t)=>new o.W(e,t).define().type})},91211:(e,t,r)=>{r.d(t,{SO:()=>h,Yl:()=>u,pc:()=>l});var s=r(40478);const n=s.P3.FAST.getById(1,(()=>{const e=[],t=[];function r(){if(t.length)throw t.shift()}function n(e){try{e.call()}catch(e){t.push(e),setTimeout(r,0)}}function i(){let t=0;for(;t<e.length;)if(n(e[t]),t++,t>1024){for(let r=0,s=e.length-t;r<s;r++)e[r]=e[r+t];e.length-=t,t=0}e.length=0}return Object.freeze({enqueue:function(t){e.length<1&&s.P3.requestAnimationFrame(i),e.push(t)},process:i})})),i=s.P3.trustedTypes.createPolicy("fast-html",{createHTML:e=>e});let o=i;const a=`fast-${Math.random().toString(36).substring(2,8)}`,l=`${a}{`,u=`}${a}`,h=Object.freeze({supportsAdoptedStyleSheets:Array.isArray(document.adoptedStyleSheets)&&"replace"in CSSStyleSheet.prototype,setHTMLPolicy(e){if(o!==i)throw new Error("The HTML policy can only be set once.");o=e},createHTML:e=>o.createHTML(e),isMarker:e=>e&&8===e.nodeType&&e.data.startsWith(a),extractDirectiveIndexFromMarker:e=>parseInt(e.data.replace(`${a}:`,"")),createInterpolationPlaceholder:e=>`${l}${e}${u}`,createCustomAttributePlaceholder(e,t){return`${e}="${this.createInterpolationPlaceholder(t)}"`},createBlockPlaceholder:e=>`\x3c!--${a}:${e}--\x3e`,queueUpdate:n.enqueue,processUpdates:n.process,nextUpdate:()=>new Promise(n.enqueue),setAttribute(e,t,r){null==r?e.removeAttribute(t):e.setAttribute(t,r)},setBooleanAttribute(e,t,r){r?e.setAttribute(t,""):e.removeAttribute(t)},removeChildNodes(e){for(let t=e.firstChild;null!==t;t=e.firstChild)e.removeChild(t)},createTemplateWalker:e=>document.createTreeWalker(e,133,null,!1)})},8111:(e,t,r)=>{r.d(t,{A:()=>n,q:()=>s});class s{constructor(e,t){this.sub1=void 0,this.sub2=void 0,this.spillover=void 0,this.source=e,this.sub1=t}has(e){return void 0===this.spillover?this.sub1===e||this.sub2===e:-1!==this.spillover.indexOf(e)}subscribe(e){const t=this.spillover;if(void 0===t){if(this.has(e))return;if(void 0===this.sub1)return void(this.sub1=e);if(void 0===this.sub2)return void(this.sub2=e);this.spillover=[this.sub1,this.sub2,e],this.sub1=void 0,this.sub2=void 0}else-1===t.indexOf(e)&&t.push(e)}unsubscribe(e){const t=this.spillover;if(void 0===t)this.sub1===e?this.sub1=void 0:this.sub2===e&&(this.sub2=void 0);else{const r=t.indexOf(e);-1!==r&&t.splice(r,1)}}notify(e){const t=this.spillover,r=this.source;if(void 0===t){const t=this.sub1,s=this.sub2;void 0!==t&&t.handleChange(r,e),void 0!==s&&s.handleChange(r,e)}else for(let s=0,n=t.length;s<n;++s)t[s].handleChange(r,e)}}class n{constructor(e){this.subscribers={},this.sourceSubscribers=null,this.source=e}notify(e){var t;const r=this.subscribers[e];void 0!==r&&r.notify(e),null===(t=this.sourceSubscribers)||void 0===t||t.notify(e)}subscribe(e,t){var r;if(t){let r=this.subscribers[t];void 0===r&&(this.subscribers[t]=r=new s(this.source)),r.subscribe(e)}else this.sourceSubscribers=null!==(r=this.sourceSubscribers)&&void 0!==r?r:new s(this.source),this.sourceSubscribers.subscribe(e)}unsubscribe(e,t){var r;if(t){const r=this.subscribers[t];void 0!==r&&r.unsubscribe(e)}else null===(r=this.sourceSubscribers)||void 0===r||r.unsubscribe(e)}}},92221:(e,t,r)=>{r.d(t,{LO:()=>a,Wp:()=>h,rd:()=>u,y$:()=>o});var s=r(91211),n=r(40478),i=r(8111);const o=n.Bo.getById(2,(()=>{const e=/(:|&&|\|\||if)/,t=new WeakMap,r=s.SO.queueUpdate;let o,a=e=>{throw new Error("Must call enableArrayObservation before observing arrays.")};function l(e){let r=e.$fastController||t.get(e);return void 0===r&&(Array.isArray(e)?r=a(e):t.set(e,r=new i.A(e))),r}const u=(0,n.j8)();class h{constructor(e){this.name=e,this.field=`_${e}`,this.callback=`${e}Changed`}getValue(e){return void 0!==o&&o.watch(e,this.name),e[this.field]}setValue(e,t){const r=this.field,s=e[r];if(s!==t){e[r]=t;const n=e[this.callback];"function"==typeof n&&n.call(e,s,t),l(e).notify(this.name)}}}class c extends i.q{constructor(e,t,r=!1){super(e,t),this.binding=e,this.isVolatileBinding=r,this.needsRefresh=!0,this.needsQueue=!0,this.first=this,this.last=null,this.propertySource=void 0,this.propertyName=void 0,this.notifier=void 0,this.next=void 0}observe(e,t){this.needsRefresh&&null!==this.last&&this.disconnect();const r=o;o=this.needsRefresh?this:void 0,this.needsRefresh=this.isVolatileBinding;const s=this.binding(e,t);return o=r,s}disconnect(){if(null!==this.last){let e=this.first;for(;void 0!==e;)e.notifier.unsubscribe(this,e.propertyName),e=e.next;this.last=null,this.needsRefresh=this.needsQueue=!0}}watch(e,t){const r=this.last,s=l(e),n=null===r?this.first:{};if(n.propertySource=e,n.propertyName=t,n.notifier=s,s.subscribe(this,t),null!==r){if(!this.needsRefresh){let t;o=void 0,t=r.propertySource[r.propertyName],o=this,e===t&&(this.needsRefresh=!0)}r.next=n}this.last=n}handleChange(){this.needsQueue&&(this.needsQueue=!1,r(this))}call(){null!==this.last&&(this.needsQueue=!0,this.notify(this))}records(){let e=this.first;return{next:()=>{const t=e;return void 0===t?{value:void 0,done:!0}:(e=e.next,{value:t,done:!1})},[Symbol.iterator]:function(){return this}}}}return Object.freeze({setArrayObserverFactory(e){a=e},getNotifier:l,track(e,t){void 0!==o&&o.watch(e,t)},trackVolatile(){void 0!==o&&(o.needsRefresh=!0)},notify(e,t){l(e).notify(t)},defineProperty(e,t){"string"==typeof t&&(t=new h(t)),u(e).push(t),Reflect.defineProperty(e,t.name,{enumerable:!0,get:function(){return t.getValue(this)},set:function(e){t.setValue(this,e)}})},getAccessors:u,binding(e,t,r=this.isVolatileBinding(e)){return new c(e,t,r)},isVolatileBinding:t=>e.test(t.toString())})}));function a(e,t){o.defineProperty(e,t)}const l=n.Bo.getById(3,(()=>{let e=null;return{get:()=>e,set(t){e=t}}}));class u{constructor(){this.index=0,this.length=0,this.parent=null,this.parentContext=null}get event(){return l.get()}get isEven(){return this.index%2==0}get isOdd(){return this.index%2!=0}get isFirst(){return 0===this.index}get isInMiddle(){return!this.isFirst&&!this.isLast}get isLast(){return this.index===this.length-1}static setEvent(e){l.set(e)}}o.defineProperty(u.prototype,"index"),o.defineProperty(u.prototype,"length");const h=Object.seal(new u)},40478:(e,t,r)=>{r.d(t,{Bo:()=>i,P3:()=>s,j8:()=>a,ow:()=>o});const s=function(){if("undefined"!=typeof globalThis)return globalThis;if(void 0!==r.g)return r.g;if("undefined"!=typeof self)return self;if("undefined"!=typeof window)return window;try{return new Function("return this")()}catch(e){return{}}}();void 0===s.trustedTypes&&(s.trustedTypes={createPolicy:(e,t)=>t});const n={configurable:!1,enumerable:!1,writable:!1};void 0===s.FAST&&Reflect.defineProperty(s,"FAST",Object.assign({value:Object.create(null)},n));const i=s.FAST;if(void 0===i.getById){const e=Object.create(null);Reflect.defineProperty(i,"getById",Object.assign({value(t,r){let s=e[t];return void 0===s&&(s=r?e[t]=r():null),s}},n))}const o=Object.freeze([]);function a(){const e=new WeakMap;return function(t){let r=e.get(t);if(void 0===r){let s=Reflect.getPrototypeOf(t);for(;void 0===r&&null!==s;)r=e.get(s),s=Reflect.getPrototypeOf(s);r=void 0===r?[]:r.slice(0),e.set(t,r)}return r}}},37202:(e,t,r)=>{r.d(t,{v:()=>s});class s{createCSS(){return""}createBehavior(){}}},12634:(e,t,r)=>{r.d(t,{i:()=>o,j:()=>l});var s=r(37202),n=r(60956);function i(e,t){const r=[];let i="";const o=[];for(let a=0,l=e.length-1;a<l;++a){i+=e[a];let l=t[a];if(l instanceof s.v){const e=l.createBehavior();l=l.createCSS(),e&&o.push(e)}l instanceof n.XL||l instanceof CSSStyleSheet?(""!==i.trim()&&(r.push(i),i=""),r.push(l)):i+=l}return i+=e[e.length-1],""!==i.trim()&&r.push(i),{styles:r,behaviors:o}}function o(e,...t){const{styles:r,behaviors:s}=i(e,t),o=n.XL.create(r);return s.length&&o.withBehaviors(...s),o}class a extends s.v{constructor(e,t){super(),this.behaviors=t,this.css="";const r=e.reduce(((e,t)=>("string"==typeof t?this.css+=t:e.push(t),e)),[]);r.length&&(this.styles=n.XL.create(r))}createBehavior(){return this}createCSS(){return this.css}bind(e){this.styles&&e.$fastController.addStyles(this.styles),this.behaviors.length&&e.$fastController.addBehaviors(this.behaviors)}unbind(e){this.styles&&e.$fastController.removeStyles(this.styles),this.behaviors.length&&e.$fastController.removeBehaviors(this.behaviors)}}function l(e,...t){const{styles:r,behaviors:s}=i(e,t);return new a(r,s)}},60956:(e,t,r)=>{r.d(t,{XL:()=>n});var s=r(91211);class n{constructor(){this.targets=new WeakSet}addStylesTo(e){this.targets.add(e)}removeStylesFrom(e){this.targets.delete(e)}isAttachedTo(e){return this.targets.has(e)}withBehaviors(...e){return this.behaviors=null===this.behaviors?e:this.behaviors.concat(e),this}}function i(e){return e.map((e=>e instanceof n?i(e.styles):[e])).reduce(((e,t)=>e.concat(t)),[])}function o(e){return e.map((e=>e instanceof n?e.behaviors:null)).reduce(((e,t)=>null===t?e:(null===e&&(e=[]),e.concat(t))),null)}n.create=(()=>{if(s.SO.supportsAdoptedStyleSheets){const e=new Map;return t=>new u(t,e)}return e=>new c(e)})();let a=(e,t)=>{e.adoptedStyleSheets=[...e.adoptedStyleSheets,...t]},l=(e,t)=>{e.adoptedStyleSheets=e.adoptedStyleSheets.filter((e=>-1===t.indexOf(e)))};if(s.SO.supportsAdoptedStyleSheets)try{document.adoptedStyleSheets.push(),document.adoptedStyleSheets.splice(),a=(e,t)=>{e.adoptedStyleSheets.push(...t)},l=(e,t)=>{for(const r of t){const t=e.adoptedStyleSheets.indexOf(r);-1!==t&&e.adoptedStyleSheets.splice(t,1)}}}catch(e){}class u extends n{constructor(e,t){super(),this.styles=e,this.styleSheetCache=t,this._styleSheets=void 0,this.behaviors=o(e)}get styleSheets(){if(void 0===this._styleSheets){const e=this.styles,t=this.styleSheetCache;this._styleSheets=i(e).map((e=>{if(e instanceof CSSStyleSheet)return e;let r=t.get(e);return void 0===r&&(r=new CSSStyleSheet,r.replaceSync(e),t.set(e,r)),r}))}return this._styleSheets}addStylesTo(e){a(e,this.styleSheets),super.addStylesTo(e)}removeStylesFrom(e){l(e,this.styleSheets),super.removeStylesFrom(e)}}let h=0;class c extends n{constructor(e){super(),this.styles=e,this.behaviors=null,this.behaviors=o(e),this.styleSheets=i(e),this.styleClass="fast-style-class-"+ ++h}addStylesTo(e){const t=this.styleSheets,r=this.styleClass;e=this.normalizeTarget(e);for(let s=0;s<t.length;s++){const n=document.createElement("style");n.innerHTML=t[s],n.className=r,e.append(n)}super.addStylesTo(e)}removeStylesFrom(e){const t=(e=this.normalizeTarget(e)).querySelectorAll(`.${this.styleClass}`);for(let r=0,s=t.length;r<s;++r)e.removeChild(t[r]);super.removeStylesFrom(e)}isAttachedTo(e){return super.isAttachedTo(this.normalizeTarget(e))}normalizeTarget(e){return e===document?document.body:e}}},82683:(e,t,r)=>{r.d(t,{ON:()=>o,d$:()=>i,m0:()=>n});var s=r(91211);class n{constructor(){this.targetIndex=0}}class i extends n{constructor(){super(...arguments),this.createPlaceholder=s.SO.createInterpolationPlaceholder}}class o extends n{constructor(e,t,r){super(),this.name=e,this.behavior=t,this.options=r}createPlaceholder(e){return s.SO.createCustomAttributePlaceholder(this.name,e)}createBehavior(e){return new this.behavior(e,this.options)}}},41681:(e,t,r)=>{r.d(t,{R:()=>i,x:()=>o});var s=r(92221),n=r(40478);function i(e){return e?function(t,r,s){return 1===t.nodeType&&t.matches(e)}:function(e,t,r){return 1===e.nodeType}}class o{constructor(e,t){this.target=e,this.options=t,this.source=null}bind(e){const t=this.options.property;this.shouldUpdate=s.y$.getAccessors(e).some((e=>e.name===t)),this.source=e,this.updateTarget(this.computeNodes()),this.shouldUpdate&&this.observe()}unbind(){this.updateTarget(n.ow),this.source=null,this.shouldUpdate&&this.disconnect()}handleEvent(){this.updateTarget(this.computeNodes())}computeNodes(){let e=this.getNodes();return void 0!==this.options.filter&&(e=e.filter(this.options.filter)),e}updateTarget(e){this.source[this.options.property]=e}}},62564:(e,t,r)=>{r.d(t,{i:()=>i});var s=r(82683);class n{constructor(e,t){this.target=e,this.propertyName=t}bind(e){e[this.propertyName]=this.target}unbind(){}}function i(e){return new s.ON("fast-ref",n,e)}},17832:(e,t,r)=>{r.d(t,{Q:()=>o});var s=r(82683),n=r(41681);class i extends n.x{constructor(e,t){super(e,t)}observe(){this.target.addEventListener("slotchange",this)}disconnect(){this.target.removeEventListener("slotchange",this)}getNodes(){return this.target.assignedNodes(this.options)}}function o(e){return"string"==typeof e&&(e={property:e}),new s.ON("fast-slotted",i,e)}},25269:(e,t,r)=>{r.d(t,{d:()=>$});var s=r(91211),n=r(92221),i=r(82683);function o(e,t){this.source=e,this.context=t,null===this.bindingObserver&&(this.bindingObserver=n.y$.binding(this.binding,this,this.isBindingVolatile)),this.updateTarget(this.bindingObserver.observe(e,t))}function a(e,t){this.source=e,this.context=t,this.target.addEventListener(this.targetName,this)}function l(){this.bindingObserver.disconnect(),this.source=null,this.context=null}function u(){this.bindingObserver.disconnect(),this.source=null,this.context=null;const e=this.target.$fastView;void 0!==e&&e.isComposed&&(e.unbind(),e.needsBindOnly=!0)}function h(){this.target.removeEventListener(this.targetName,this),this.source=null,this.context=null}function c(e){s.SO.setAttribute(this.target,this.targetName,e)}function d(e){s.SO.setBooleanAttribute(this.target,this.targetName,e)}function g(e){if(null==e&&(e=""),e.create){this.target.textContent="";let t=this.target.$fastView;void 0===t?t=e.create():this.target.$fastTemplate!==e&&(t.isComposed&&(t.remove(),t.unbind()),t=e.create()),t.isComposed?t.needsBindOnly&&(t.needsBindOnly=!1,t.bind(this.source,this.context)):(t.isComposed=!0,t.bind(this.source,this.context),t.insertBefore(this.target),this.target.$fastView=t,this.target.$fastTemplate=e)}else{const t=this.target.$fastView;void 0!==t&&t.isComposed&&(t.isComposed=!1,t.remove(),t.needsBindOnly?t.needsBindOnly=!1:t.unbind()),this.target.textContent=e}}function f(e){this.target[this.targetName]=e}function p(e){const t=this.classVersions||Object.create(null),r=this.target;let s=this.version||0;if(null!=e&&e.length){const n=e.split(/\s+/);for(let e=0,i=n.length;e<i;++e){const i=n[e];""!==i&&(t[i]=s,r.classList.add(i))}}if(this.classVersions=t,this.version=s+1,0!==s){s-=1;for(const e in t)t[e]===s&&r.classList.remove(e)}}class b extends i.d${constructor(e){super(),this.binding=e,this.bind=o,this.unbind=l,this.updateTarget=c,this.isBindingVolatile=n.y$.isVolatileBinding(this.binding)}get targetName(){return this.originalTargetName}set targetName(e){if(this.originalTargetName=e,void 0!==e)switch(e[0]){case":":if(this.cleanedTargetName=e.substr(1),this.updateTarget=f,"innerHTML"===this.cleanedTargetName){const e=this.binding;this.binding=(t,r)=>s.SO.createHTML(e(t,r))}break;case"?":this.cleanedTargetName=e.substr(1),this.updateTarget=d;break;case"@":this.cleanedTargetName=e.substr(1),this.bind=a,this.unbind=h;break;default:this.cleanedTargetName=e,"class"===e&&(this.updateTarget=p)}}targetAtContent(){this.updateTarget=g,this.unbind=u}createBehavior(e){return new v(e,this.binding,this.isBindingVolatile,this.bind,this.unbind,this.updateTarget,this.cleanedTargetName)}}class v{constructor(e,t,r,s,n,i,o){this.source=null,this.context=null,this.bindingObserver=null,this.target=e,this.binding=t,this.isBindingVolatile=r,this.bind=s,this.unbind=n,this.updateTarget=i,this.targetName=o}handleChange(){this.updateTarget(this.bindingObserver.observe(this.source,this.context))}handleEvent(e){n.rd.setEvent(e);const t=this.binding(this.source,this.context);n.rd.setEvent(null),!0!==t&&e.preventDefault()}}let m=null;class y{addFactory(e){e.targetIndex=this.targetIndex,this.behaviorFactories.push(e)}captureContentBinding(e){e.targetAtContent(),this.addFactory(e)}reset(){this.behaviorFactories=[],this.targetIndex=-1}release(){m=this}static borrow(e){const t=m||new y;return t.directives=e,t.reset(),m=null,t}}function w(e){if(1===e.length)return e[0];let t;const r=e.length,s=e.map((e=>"string"==typeof e?()=>e:(t=e.targetName||t,e.binding))),n=new b(((e,t)=>{let n="";for(let i=0;i<r;++i)n+=s[i](e,t);return n}));return n.targetName=t,n}const C=s.Yl.length;function x(e,t){const r=t.split(s.pc);if(1===r.length)return null;const n=[];for(let t=0,i=r.length;t<i;++t){const i=r[t],o=i.indexOf(s.Yl);let a;if(-1===o)a=i;else{const t=parseInt(i.substring(0,o));n.push(e.directives[t]),a=i.substring(o+C)}""!==a&&n.push(a)}return n}function V(e,t,r=!1){const s=t.attributes;for(let n=0,i=s.length;n<i;++n){const o=s[n],a=o.value,l=x(e,a);let u=null;null===l?r&&(u=new b((()=>a)),u.targetName=o.name):u=w(l),null!==u&&(t.removeAttributeNode(o),n--,i--,e.addFactory(u))}}function F(e,t,r){const s=x(e,t.textContent);if(null!==s){let n=t;for(let i=0,o=s.length;i<o;++i){const o=s[i],a=0===i?t:n.parentNode.insertBefore(document.createTextNode(""),n.nextSibling);"string"==typeof o?a.textContent=o:(a.textContent=" ",e.captureContentBinding(o)),n=a,e.targetIndex++,a!==t&&r.nextNode()}e.targetIndex--}}const O=document.createRange();class D{constructor(e,t){this.fragment=e,this.behaviors=t,this.source=null,this.context=null,this.firstChild=e.firstChild,this.lastChild=e.lastChild}appendTo(e){e.appendChild(this.fragment)}insertBefore(e){if(this.fragment.hasChildNodes())e.parentNode.insertBefore(this.fragment,e);else{const t=this.lastChild;if(e.previousSibling===t)return;const r=e.parentNode;let s,n=this.firstChild;for(;n!==t;)s=n.nextSibling,r.insertBefore(n,e),n=s;r.insertBefore(t,e)}}remove(){const e=this.fragment,t=this.lastChild;let r,s=this.firstChild;for(;s!==t;)r=s.nextSibling,e.appendChild(s),s=r;e.appendChild(t)}dispose(){const e=this.firstChild.parentNode,t=this.lastChild;let r,s=this.firstChild;for(;s!==t;)r=s.nextSibling,e.removeChild(s),s=r;e.removeChild(t);const n=this.behaviors,i=this.source;for(let e=0,t=n.length;e<t;++e)n[e].unbind(i)}bind(e,t){const r=this.behaviors;if(this.source!==e)if(null!==this.source){const s=this.source;this.source=e,this.context=t;for(let n=0,i=r.length;n<i;++n){const i=r[n];i.unbind(s),i.bind(e,t)}}else{this.source=e,this.context=t;for(let s=0,n=r.length;s<n;++s)r[s].bind(e,t)}}unbind(){if(null===this.source)return;const e=this.behaviors,t=this.source;for(let r=0,s=e.length;r<s;++r)e[r].unbind(t);this.source=null}static disposeContiguousBatch(e){if(0!==e.length){O.setStartBefore(e[0].firstChild),O.setEndAfter(e[e.length-1].lastChild),O.deleteContents();for(let t=0,r=e.length;t<r;++t){const r=e[t],s=r.behaviors,n=r.source;for(let e=0,t=s.length;e<t;++e)s[e].unbind(n)}}}}class k{constructor(e,t){this.behaviorCount=0,this.hasHostBehaviors=!1,this.fragment=null,this.targetOffset=0,this.viewBehaviorFactories=null,this.hostBehaviorFactories=null,this.html=e,this.directives=t}create(e){if(null===this.fragment){let e;const t=this.html;if("string"==typeof t){e=document.createElement("template"),e.innerHTML=s.SO.createHTML(t);const r=e.content.firstElementChild;null!==r&&"TEMPLATE"===r.tagName&&(e=r)}else e=t;const r=function(e,t){const r=e.content;document.adoptNode(r);const n=y.borrow(t);V(n,e,!0);const i=n.behaviorFactories;n.reset();const o=s.SO.createTemplateWalker(r);let a;for(;a=o.nextNode();)switch(n.targetIndex++,a.nodeType){case 1:V(n,a);break;case 3:F(n,a,o);break;case 8:s.SO.isMarker(a)&&n.addFactory(t[s.SO.extractDirectiveIndexFromMarker(a)])}let l=0;(s.SO.isMarker(r.firstChild)||1===r.childNodes.length&&t.length)&&(r.insertBefore(document.createComment(""),r.firstChild),l=-1);const u=n.behaviorFactories;return n.release(),{fragment:r,viewBehaviorFactories:u,hostBehaviorFactories:i,targetOffset:l}}(e,this.directives);this.fragment=r.fragment,this.viewBehaviorFactories=r.viewBehaviorFactories,this.hostBehaviorFactories=r.hostBehaviorFactories,this.targetOffset=r.targetOffset,this.behaviorCount=this.viewBehaviorFactories.length+this.hostBehaviorFactories.length,this.hasHostBehaviors=this.hostBehaviorFactories.length>0}const t=this.fragment.cloneNode(!0),r=this.viewBehaviorFactories,n=new Array(this.behaviorCount),i=s.SO.createTemplateWalker(t);let o=0,a=this.targetOffset,l=i.nextNode();for(let e=r.length;o<e;++o){const e=r[o],t=e.targetIndex;for(;null!==l;){if(a===t){n[o]=e.createBehavior(l);break}l=i.nextNode(),a++}}if(this.hasHostBehaviors){const t=this.hostBehaviorFactories;for(let r=0,s=t.length;r<s;++r,++o)n[o]=t[r].createBehavior(e)}return new D(t,n)}render(e,t,r){"string"==typeof t&&(t=document.getElementById(t)),void 0===r&&(r=t);const s=this.create(r);return s.bind(e,n.Wp),s.appendTo(t),s}}const S=/([ \x09\x0a\x0c\x0d])([^\0-\x1F\x7F-\x9F "'>=/]+)([ \x09\x0a\x0c\x0d]*=[ \x09\x0a\x0c\x0d]*(?:[^ \x09\x0a\x0c\x0d"'`<>=]*|"[^"]*|'[^']*))$/;function $(e,...t){const r=[];let s="";for(let n=0,o=e.length-1;n<o;++n){const o=e[n];let a=t[n];if(s+=o,a instanceof k){const e=a;a=()=>e}if("function"==typeof a&&(a=new b(a)),a instanceof i.d$){const e=S.exec(o);null!==e&&(a.targetName=e[2])}a instanceof i.m0?(s+=a.createPlaceholder(r.length),r.push(a)):s+=a}return s+=e[e.length-1],new k(s,r)}},40791:(e,t,r)=>{r.d(t,{B:()=>l,v:()=>a});var s=r(60956),n=r(70529);function i(e){return`${e.toLowerCase()}:presentation`}const o=new Map,a=Object.freeze({define(e,t,r){const s=i(e);void 0===o.get(s)?o.set(s,t):o.set(s,!1),r.register(n.YM.instance(s,t))},forTag(e,t){const r=i(e),s=o.get(r);return!1===s?n.DI.findResponsibleContainer(t).get(r):s||null}});class l{constructor(e,t){this.template=e||null,this.styles=void 0===t?null:Array.isArray(t)?s.XL.create(t):t instanceof s.XL?t:s.XL.create([t])}applyTo(e){const t=e.$fastController;null===t.template&&(t.template=this.template),null===t.styles&&(t.styles=this.styles)}}},27002:(e,t,r)=>{r.d(t,{DesignToken:()=>D});var s=r(95185),n=r(37202),i=r(92221),o=r(58930),a=r(75494),l=r(91211),u=r(60956);const h=document.createElement("div");class c{setProperty(e,t){l.SO.queueUpdate((()=>this.target.setProperty(e,t)))}removeProperty(e){l.SO.queueUpdate((()=>this.target.removeProperty(e)))}}class d extends c{constructor(){super();const e=new CSSStyleSheet;this.target=e.cssRules[e.insertRule(":root{}")].style,document.adoptedStyleSheets=[...document.adoptedStyleSheets,e]}}class g extends c{constructor(){super(),this.style=document.createElement("style"),document.head.appendChild(this.style);const{sheet:e}=this.style;if(e){const t=e.insertRule(":root{}",e.cssRules.length);this.target=e.cssRules[t].style}}}class f{constructor(e){this.store=new Map,this.target=null;const t=e.$fastController;this.style=document.createElement("style"),t.addStyles(this.style),i.y$.getNotifier(t).subscribe(this,"isConnected"),this.handleChange(t,"isConnected")}targetChanged(){if(null!==this.target)for(const[e,t]of this.store.entries())this.target.setProperty(e,t)}setProperty(e,t){this.store.set(e,t),l.SO.queueUpdate((()=>{null!==this.target&&this.target.setProperty(e,t)}))}removeProperty(e){this.store.delete(e),l.SO.queueUpdate((()=>{null!==this.target&&this.target.removeProperty(e)}))}handleChange(e,t){const{sheet:r}=this.style;if(r){const e=r.insertRule(":host{}",r.cssRules.length);this.target=r.cssRules[e].style}else this.target=null}}(0,s.gn)([i.LO],f.prototype,"target",void 0);class p{constructor(e){this.target=e.style}setProperty(e,t){l.SO.queueUpdate((()=>this.target.setProperty(e,t)))}removeProperty(e){l.SO.queueUpdate((()=>this.target.removeProperty(e)))}}class b{setProperty(e,t){b.properties[e]=t;for(const r of b.roots.values())y.getOrCreate(b.normalizeRoot(r)).setProperty(e,t)}removeProperty(e){delete b.properties[e];for(const t of b.roots.values())y.getOrCreate(b.normalizeRoot(t)).removeProperty(e)}static registerRoot(e){const{roots:t}=b;if(!t.has(e)){t.add(e);const r=y.getOrCreate(this.normalizeRoot(e));for(const e in b.properties)r.setProperty(e,b.properties[e])}}static unregisterRoot(e){const{roots:t}=b;if(t.has(e)){t.delete(e);const r=y.getOrCreate(b.normalizeRoot(e));for(const e in b.properties)r.removeProperty(e)}}static normalizeRoot(e){return e===h?document:e}}b.roots=new Set,b.properties={};const v=new WeakMap,m=l.SO.supportsAdoptedStyleSheets?class extends c{constructor(e){super();const t=new CSSStyleSheet;this.target=t.cssRules[t.insertRule(":host{}")].style,e.$fastController.addStyles(u.XL.create([t]))}}:f,y=Object.freeze({getOrCreate(e){if(v.has(e))return v.get(e);let t;return t=e===h?new b:e instanceof Document?l.SO.supportsAdoptedStyleSheets?new d:new g:e instanceof o.H?new m(e):new p(e),v.set(e,t),t}});class w extends n.v{constructor(e){super(),this.subscribers=new WeakMap,this._appliedTo=new Set,this.name=e.name,null!==e.cssCustomPropertyName&&(this.cssCustomProperty=`--${e.cssCustomPropertyName}`,this.cssVar=`var(${this.cssCustomProperty})`),this.id=w.uniqueId(),w.tokensById.set(this.id,this)}get appliedTo(){return[...this._appliedTo]}static from(e){return new w({name:"string"==typeof e?e:e.name,cssCustomPropertyName:"string"==typeof e?e:void 0===e.cssCustomPropertyName?e.name:e.cssCustomPropertyName})}static isCSSDesignToken(e){return"string"==typeof e.cssCustomProperty}static isDerivedDesignTokenValue(e){return"function"==typeof e}static getTokenById(e){return w.tokensById.get(e)}getOrCreateSubscriberSet(e=this){return this.subscribers.get(e)||this.subscribers.set(e,new Set)&&this.subscribers.get(e)}createCSS(){return this.cssVar||""}getValueFor(e){const t=O.getOrCreate(e).get(this);if(void 0!==t)return t;throw new Error(`Value could not be retrieved for token named "${this.name}". Ensure the value is set for ${e} or an ancestor of ${e}.`)}setValueFor(e,t){return this._appliedTo.add(e),t instanceof w&&(t=this.alias(t)),O.getOrCreate(e).set(this,t),this}deleteValueFor(e){return this._appliedTo.delete(e),O.existsFor(e)&&O.getOrCreate(e).delete(this),this}withDefault(e){return this.setValueFor(h,e),this}subscribe(e,t){const r=this.getOrCreateSubscriberSet(t);t&&!O.existsFor(t)&&O.getOrCreate(t),r.has(e)||r.add(e)}unsubscribe(e,t){const r=this.subscribers.get(t||this);r&&r.has(e)&&r.delete(e)}notify(e){const t=Object.freeze({token:this,target:e});this.subscribers.has(this)&&this.subscribers.get(this).forEach((e=>e.handleChange(t))),this.subscribers.has(e)&&this.subscribers.get(e).forEach((e=>e.handleChange(t)))}alias(e){return t=>e.getValueFor(t)}}w.uniqueId=(()=>{let e=0;return()=>(e++,e.toString(16))})(),w.tokensById=new Map;class C{constructor(e,t,r){this.source=e,this.token=t,this.node=r,this.dependencies=new Set,this.observer=i.y$.binding(e,this,!1),this.observer.handleChange=this.observer.call,this.handleChange()}disconnect(){this.observer.disconnect()}handleChange(){this.node.store.set(this.token,this.observer.observe(this.node.target,i.Wp))}}class x{constructor(){this.values=new Map}set(e,t){this.values.get(e)!==t&&(this.values.set(e,t),i.y$.getNotifier(this).notify(e.id))}get(e){return i.y$.track(this,e.id),this.values.get(e)}delete(e){this.values.delete(e)}all(){return this.values.entries()}}const V=new WeakMap,F=new WeakMap;class O{constructor(e){this.target=e,this.store=new x,this.children=[],this.assignedValues=new Map,this.reflecting=new Set,this.bindingObservers=new Map,this.tokenValueChangeHandler={handleChange:(e,t)=>{const r=w.getTokenById(t);r&&(r.notify(this.target),this.updateCSSTokenReflection(e,r))}},V.set(e,this),i.y$.getNotifier(this.store).subscribe(this.tokenValueChangeHandler),e instanceof o.H?e.$fastController.addBehaviors([this]):e.isConnected&&this.bind()}static getOrCreate(e){return V.get(e)||new O(e)}static existsFor(e){return V.has(e)}static findParent(e){if(h!==e.target){let t=(0,a.T)(e.target);for(;null!==t;){if(V.has(t))return V.get(t);t=(0,a.T)(t)}return O.getOrCreate(h)}return null}static findClosestAssignedNode(e,t){let r=t;do{if(r.has(e))return r;r=r.parent?r.parent:r.target!==h?O.getOrCreate(h):null}while(null!==r);return null}get parent(){return F.get(this)||null}updateCSSTokenReflection(e,t){if(w.isCSSDesignToken(t)){const r=this.parent,s=this.isReflecting(t);if(r){const n=r.get(t),i=e.get(t);n===i||s?n===i&&s&&this.stopReflectToCSS(t):this.reflectToCSS(t)}else s||this.reflectToCSS(t)}}has(e){return this.assignedValues.has(e)}get(e){const t=this.store.get(e);if(void 0!==t)return t;const r=this.getRaw(e);return void 0!==r?(this.hydrate(e,r),this.get(e)):void 0}getRaw(e){var t;return this.assignedValues.has(e)?this.assignedValues.get(e):null===(t=O.findClosestAssignedNode(e,this))||void 0===t?void 0:t.getRaw(e)}set(e,t){w.isDerivedDesignTokenValue(this.assignedValues.get(e))&&this.tearDownBindingObserver(e),this.assignedValues.set(e,t),w.isDerivedDesignTokenValue(t)?this.setupBindingObserver(e,t):this.store.set(e,t)}delete(e){this.assignedValues.delete(e),this.tearDownBindingObserver(e);const t=this.getRaw(e);t?this.hydrate(e,t):this.store.delete(e)}bind(){const e=O.findParent(this);e&&e.appendChild(this);for(const e of this.assignedValues.keys())e.notify(this.target)}unbind(){this.parent&&F.get(this).removeChild(this)}appendChild(e){e.parent&&F.get(e).removeChild(e);const t=this.children.filter((t=>e.contains(t)));F.set(e,this),this.children.push(e),t.forEach((t=>e.appendChild(t))),i.y$.getNotifier(this.store).subscribe(e);for(const[t,r]of this.store.all())e.hydrate(t,this.bindingObservers.has(t)?this.getRaw(t):r)}removeChild(e){const t=this.children.indexOf(e);return-1!==t&&this.children.splice(t,1),i.y$.getNotifier(this.store).unsubscribe(e),e.parent===this&&F.delete(e)}contains(e){return function(e,t){let r=t;for(;null!==r;){if(r===e)return!0;r=(0,a.T)(r)}return!1}(this.target,e.target)}reflectToCSS(e){this.isReflecting(e)||(this.reflecting.add(e),O.cssCustomPropertyReflector.startReflection(e,this.target))}stopReflectToCSS(e){this.isReflecting(e)&&(this.reflecting.delete(e),O.cssCustomPropertyReflector.stopReflection(e,this.target))}isReflecting(e){return this.reflecting.has(e)}handleChange(e,t){const r=w.getTokenById(t);r&&(this.hydrate(r,this.getRaw(r)),this.updateCSSTokenReflection(this.store,r))}hydrate(e,t){if(!this.has(e)){const r=this.bindingObservers.get(e);w.isDerivedDesignTokenValue(t)?r?r.source!==t&&(this.tearDownBindingObserver(e),this.setupBindingObserver(e,t)):this.setupBindingObserver(e,t):(r&&this.tearDownBindingObserver(e),this.store.set(e,t))}}setupBindingObserver(e,t){const r=new C(t,e,this);return this.bindingObservers.set(e,r),r}tearDownBindingObserver(e){return!!this.bindingObservers.has(e)&&(this.bindingObservers.get(e).disconnect(),this.bindingObservers.delete(e),!0)}}O.cssCustomPropertyReflector=new class{startReflection(e,t){e.subscribe(this,t),this.handleChange({token:e,target:t})}stopReflection(e,t){e.unsubscribe(this,t),this.remove(e,t)}handleChange(e){const{token:t,target:r}=e;this.add(t,r)}add(e,t){y.getOrCreate(t).setProperty(e.cssCustomProperty,this.resolveCSSValue(O.getOrCreate(t).get(e)))}remove(e,t){y.getOrCreate(t).removeProperty(e.cssCustomProperty)}resolveCSSValue(e){return e&&"function"==typeof e.createCSS?e.createCSS():e}},(0,s.gn)([i.LO],O.prototype,"children",void 0);const D=Object.freeze({create:function(e){return w.from(e)},notifyConnection:e=>!(!e.isConnected||!O.existsFor(e)||(O.getOrCreate(e).bind(),0)),notifyDisconnection:e=>!(e.isConnected||!O.existsFor(e)||(O.getOrCreate(e).unbind(),0)),registerRoot(e=h){b.registerRoot(e)},unregisterRoot(e=h){b.unregisterRoot(e)}})},70529:(e,t,r)=>{r.d(t,{DI:()=>g,YM:()=>L});var s=r(58930),n=r(40478);const i=new Map;"metadata"in Reflect||(Reflect.metadata=function(e,t){return function(r){Reflect.defineMetadata(e,t,r)}},Reflect.defineMetadata=function(e,t,r){let s=i.get(r);void 0===s&&i.set(r,s=new Map),s.set(e,t)},Reflect.getOwnMetadata=function(e,t){const r=i.get(t);if(void 0!==r)return r.get(e)});class o{constructor(e,t){this.container=e,this.key=t}instance(e){return this.registerResolver(0,e)}singleton(e){return this.registerResolver(1,e)}transient(e){return this.registerResolver(2,e)}callback(e){return this.registerResolver(3,e)}cachedCallback(e){return this.registerResolver(3,P(e))}aliasTo(e){return this.registerResolver(5,e)}registerResolver(e,t){const{container:r,key:s}=this;return this.container=this.key=void 0,r.registerResolver(s,new y(s,e,t))}}function a(e){const t=e.slice(),r=Object.keys(e),s=r.length;let n;for(let i=0;i<s;++i)n=r[i],B(n)||(t[n]=e[n]);return t}const l=Object.freeze({none(e){throw Error(`${e.toString()} not registered, did you forget to add @singleton()?`)},singleton:e=>new y(e,1,e),transient:e=>new y(e,2,e)}),u=Object.freeze({default:Object.freeze({parentLocator:()=>null,responsibleForOwnerRequests:!1,defaultResolver:l.singleton})}),h=new Map;function c(e){return t=>Reflect.getOwnMetadata(e,t)}let d=null;const g=Object.freeze({createContainer:e=>new $(null,Object.assign({},u.default,e)),findResponsibleContainer(e){const t=e.$$container$$;return t&&t.responsibleForOwnerRequests?t:g.findParentContainer(e)},findParentContainer(e){const t=new CustomEvent(k,{bubbles:!0,composed:!0,cancelable:!0,detail:{container:void 0}});return e.dispatchEvent(t),t.detail.container||g.getOrCreateDOMContainer()},getOrCreateDOMContainer:(e,t)=>e?e.$$container$$||new $(e,Object.assign({},u.default,t,{parentLocator:g.findParentContainer})):d||(d=new $(null,Object.assign({},u.default,t,{parentLocator:()=>null}))),getDesignParamtypes:c("design:paramtypes"),getAnnotationParamtypes:c("di:paramtypes"),getOrCreateAnnotationParamTypes(e){let t=this.getAnnotationParamtypes(e);return void 0===t&&Reflect.defineMetadata("di:paramtypes",t=[],e),t},getDependencies(e){let t=h.get(e);if(void 0===t){const r=e.inject;if(void 0===r){const r=g.getDesignParamtypes(e),s=g.getAnnotationParamtypes(e);if(void 0===r)if(void 0===s){const r=Object.getPrototypeOf(e);t="function"==typeof r&&r!==Function.prototype?a(g.getDependencies(r)):[]}else t=a(s);else if(void 0===s)t=a(r);else{t=a(r);let e,n=s.length;for(let r=0;r<n;++r)e=s[r],void 0!==e&&(t[r]=e);const i=Object.keys(s);let o;n=i.length;for(let e=0;e<n;++e)o=i[e],B(o)||(t[o]=s[o])}}else t=a(r);h.set(e,t)}return t},defineProperty(e,t,r,n=!1){const i=`$di_${t}`;Reflect.defineProperty(e,t,{get:function(){let e=this[i];if(void 0===e){const o=this instanceof HTMLElement?g.findResponsibleContainer(this):g.getOrCreateDOMContainer();if(e=o.get(r),this[i]=e,n&&this instanceof s.H){const s=this.$fastController,n=()=>{g.findResponsibleContainer(this).get(r)!==this[i]&&(this[i]=e,s.notify(t))};s.subscribe({handleChange:n},"isConnected")}}return e}})},createInterface(e,t){const r="function"==typeof e?e:t,s="string"==typeof e?e:e&&"friendlyName"in e&&e.friendlyName||M,n="string"!=typeof e&&(e&&"respectConnection"in e&&e.respectConnection||!1),i=function(e,t,r){if(null==e||void 0!==new.target)throw new Error(`No registration for interface: '${i.friendlyName}'`);t?g.defineProperty(e,t,i,n):g.getOrCreateAnnotationParamTypes(e)[r]=i};return i.$isInterface=!0,i.friendlyName=null==s?"(anonymous)":s,null!=r&&(i.register=function(e,t){return r(new o(e,null!=t?t:i))}),i.toString=function(){return`InterfaceSymbol<${i.friendlyName}>`},i},inject:(...e)=>function(t,r,s){if("number"==typeof s){const r=g.getOrCreateAnnotationParamTypes(t),n=e[0];void 0!==n&&(r[s]=n)}else if(r)g.defineProperty(t,r,e[0]);else{const r=s?g.getOrCreateAnnotationParamTypes(s.value):g.getOrCreateAnnotationParamTypes(t);let n;for(let t=0;t<e.length;++t)n=e[t],void 0!==n&&(r[t]=n)}},transient:e=>(e.register=function(t){return L.transient(e,e).register(t)},e.registerInRequestor=!1,e),singleton:(e,t=b)=>(e.register=function(t){return L.singleton(e,e).register(t)},e.registerInRequestor=t.scoped,e)}),f=g.createInterface("Container");function p(e){return function(t){const r=function(e,t,s){g.inject(r)(e,t,s)};return r.$isResolver=!0,r.resolve=function(r,s){return e(t,r,s)},r}}g.inject;const b={scoped:!1};function v(e,t,r){g.inject(v)(e,t,r)}function m(e,t){return t.getFactory(e).construct(t)}p(((e,t,r)=>()=>r.get(e))),p(((e,t,r)=>r.has(e,!0)?r.get(e):void 0)),v.$isResolver=!0,v.resolve=()=>{},p(((e,t,r)=>{const s=m(e,t),n=new y(e,0,s);return r.registerResolver(e,n),s})),p(((e,t,r)=>m(e,t)));class y{constructor(e,t,r){this.key=e,this.strategy=t,this.state=r,this.resolving=!1}get $isResolver(){return!0}register(e){return e.registerResolver(this.key,this)}resolve(e,t){switch(this.strategy){case 0:return this.state;case 1:if(this.resolving)throw new Error(`Cyclic dependency found: ${this.state.name}`);return this.resolving=!0,this.state=e.getFactory(this.state).construct(t),this.strategy=0,this.resolving=!1,this.state;case 2:{const r=e.getFactory(this.state);if(null===r)throw new Error(`Resolver for ${String(this.key)} returned a null factory`);return r.construct(t)}case 3:return this.state(e,t,this);case 4:return this.state[0].resolve(e,t);case 5:return t.get(this.state);default:throw new Error(`Invalid resolver strategy specified: ${this.strategy}.`)}}getFactory(e){var t,r,s;switch(this.strategy){case 1:case 2:return e.getFactory(this.state);case 5:return null!==(s=null===(r=null===(t=e.getResolver(this.state))||void 0===t?void 0:t.getFactory)||void 0===r?void 0:r.call(t,e))&&void 0!==s?s:null;default:return null}}}function w(e){return this.get(e)}function C(e,t){return t(e)}class x{constructor(e,t){this.Type=e,this.dependencies=t,this.transformers=null}construct(e,t){let r;return r=void 0===t?new this.Type(...this.dependencies.map(w,e)):new this.Type(...this.dependencies.map(w,e),...t),null==this.transformers?r:this.transformers.reduce(C,r)}registerTransformer(e){(this.transformers||(this.transformers=[])).push(e)}}const V={$isResolver:!0,resolve:(e,t)=>t};function F(e){return"function"==typeof e.register}function O(e){return function(e){return F(e)&&"boolean"==typeof e.registerInRequestor}(e)&&e.registerInRequestor}const D=new Set(["Array","ArrayBuffer","Boolean","DataView","Date","Error","EvalError","Float32Array","Float64Array","Function","Int8Array","Int16Array","Int32Array","Map","Number","Object","Promise","RangeError","ReferenceError","RegExp","Set","SharedArrayBuffer","String","SyntaxError","TypeError","Uint8Array","Uint8ClampedArray","Uint16Array","Uint32Array","URIError","WeakMap","WeakSet"]),k="__DI_LOCATE_PARENT__",S=new Map;class ${constructor(e,t){this.owner=e,this.config=t,this._parent=void 0,this.registerDepth=0,this.context=null,null!==e&&(e.$$container$$=this),this.resolvers=new Map,this.resolvers.set(f,V),e instanceof Node&&e.addEventListener(k,(e=>{e.composedPath()[0]!==this.owner&&(e.detail.container=this,e.stopImmediatePropagation())}))}get parent(){return void 0===this._parent&&(this._parent=this.config.parentLocator(this.owner)),this._parent}get depth(){return null===this.parent?0:this.parent.depth+1}get responsibleForOwnerRequests(){return this.config.responsibleForOwnerRequests}registerWithContext(e,...t){return this.context=e,this.register(...t),this.context=null,this}register(...e){if(100==++this.registerDepth)throw new Error("Unable to autoregister dependency");let t,r,s,n,i;const o=this.context;for(let a=0,l=e.length;a<l;++a)if(t=e[a],A(t))if(F(t))t.register(this,o);else if(void 0!==t.prototype)L.singleton(t,t).register(this);else for(r=Object.keys(t),n=0,i=r.length;n<i;++n)s=t[r[n]],A(s)&&(F(s)?s.register(this,o):this.register(s));return--this.registerDepth,this}registerResolver(e,t){R(e);const r=this.resolvers,s=r.get(e);return null==s?r.set(e,t):s instanceof y&&4===s.strategy?s.state.push(t):r.set(e,new y(e,4,[s,t])),t}registerTransformer(e,t){const r=this.getResolver(e);if(null==r)return!1;if(r.getFactory){const e=r.getFactory(this);return null!=e&&(e.registerTransformer(t),!0)}return!1}getResolver(e,t=!0){if(R(e),void 0!==e.resolve)return e;let r,s=this;for(;null!=s;){if(r=s.resolvers.get(e),null!=r)return r;if(null==s.parent){const r=O(e)?this:s;return t?this.jitRegister(e,r):null}s=s.parent}return null}has(e,t=!1){return!!this.resolvers.has(e)||!(!t||null==this.parent)&&this.parent.has(e,!0)}get(e){if(R(e),e.$isResolver)return e.resolve(this,this);let t,r=this;for(;null!=r;){if(t=r.resolvers.get(e),null!=t)return t.resolve(r,this);if(null==r.parent){const s=O(e)?this:r;return t=this.jitRegister(e,s),t.resolve(r,this)}r=r.parent}throw new Error(`Unable to resolve key: ${String(e)}`)}getAll(e,t=!1){R(e);const r=this;let s,i=r;if(t){let t=n.ow;for(;null!=i;)s=i.resolvers.get(e),null!=s&&(t=t.concat(N(s,i,r))),i=i.parent;return t}for(;null!=i;){if(s=i.resolvers.get(e),null!=s)return N(s,i,r);if(i=i.parent,null==i)return n.ow}return n.ow}getFactory(e){let t=S.get(e);if(void 0===t){if(I(e))throw new Error(`${e.name} is a native function and therefore cannot be safely constructed by DI. If this is intentional, please use a callback or cachedCallback resolver.`);S.set(e,t=new x(e,g.getDependencies(e)))}return t}registerFactory(e,t){S.set(e,t)}createChild(e){return new $(null,Object.assign({},this.config,e,{parentLocator:()=>this}))}jitRegister(e,t){if("function"!=typeof e)throw new Error(`Attempted to jitRegister something that is not a constructor: '${e}'. Did you forget to register this dependency?`);if(D.has(e.name))throw new Error(`Attempted to jitRegister an intrinsic type: ${e.name}. Did you forget to add @inject(Key)`);if(F(e)){const r=e.register(t);if(!(r instanceof Object)||null==r.resolve){const r=t.resolvers.get(e);if(null!=r)return r;throw new Error("A valid resolver was not returned from the static register method")}return r}if(e.$isInterface)throw new Error(`Attempted to jitRegister an interface: ${e.friendlyName}`);{const r=this.config.defaultResolver(e,t);return t.resolvers.set(e,r),r}}}const T=new WeakMap;function P(e){return function(t,r,s){if(T.has(s))return T.get(s);const n=e(t,r,s);return T.set(s,n),n}}const L=Object.freeze({instance:(e,t)=>new y(e,0,t),singleton:(e,t)=>new y(e,1,t),transient:(e,t)=>new y(e,2,t),callback:(e,t)=>new y(e,3,t),cachedCallback:(e,t)=>new y(e,3,P(t)),aliasTo:(e,t)=>new y(t,5,e)});function R(e){if(null==e)throw new Error("key/value cannot be null or undefined. Are you trying to inject/register something that doesn't exist with DI?")}function N(e,t,r){if(e instanceof y&&4===e.strategy){const s=e.state;let n=s.length;const i=new Array(n);for(;n--;)i[n]=s[n].resolve(t,r);return i}return[e.resolve(t,r)]}const M="(anonymous)";function A(e){return"object"==typeof e&&null!==e||"function"==typeof e}const I=function(){const e=new WeakMap;let t=!1,r="",s=0;return function(n){return t=e.get(n),void 0===t&&(r=n.toString(),s=r.length,t=s>=29&&s<=100&&125===r.charCodeAt(s-1)&&r.charCodeAt(s-2)<=32&&93===r.charCodeAt(s-3)&&101===r.charCodeAt(s-4)&&100===r.charCodeAt(s-5)&&111===r.charCodeAt(s-6)&&99===r.charCodeAt(s-7)&&32===r.charCodeAt(s-8)&&101===r.charCodeAt(s-9)&&118===r.charCodeAt(s-10)&&105===r.charCodeAt(s-11)&&116===r.charCodeAt(s-12)&&97===r.charCodeAt(s-13)&&110===r.charCodeAt(s-14)&&88===r.charCodeAt(s-15),e.set(n,t)),t}}(),j={};function B(e){switch(typeof e){case"number":return e>=0&&(0|e)===e;case"string":{const t=j[e];if(void 0!==t)return t;const r=e.length;if(0===r)return j[e]=!1;let s=0;for(let t=0;t<r;++t)if(s=e.charCodeAt(t),0===t&&48===s&&r>1||s<48||s>57)return j[e]=!1;return j[e]=!0}default:return!1}}},940:(e,t,r)=>{r.d(t,{Um:()=>d});var s=r(40478),n=r(91211),i=r(98332),o=r(92221),a=r(27081);const l="form-associated-proxy",u="ElementInternals",h=u in window&&"setFormValue"in window[u].prototype,c=new WeakMap;function d(e){const t=class extends e{constructor(...e){super(...e),this.dirtyValue=!1,this.disabled=!1,this.proxyEventsToBlock=["change","click"],this.proxyInitialized=!1,this.required=!1,this.initialValue=this.initialValue||"",this.elementInternals||(this.formResetCallback=this.formResetCallback.bind(this))}static get formAssociated(){return h}get validity(){return this.elementInternals?this.elementInternals.validity:this.proxy.validity}get form(){return this.elementInternals?this.elementInternals.form:this.proxy.form}get validationMessage(){return this.elementInternals?this.elementInternals.validationMessage:this.proxy.validationMessage}get willValidate(){return this.elementInternals?this.elementInternals.willValidate:this.proxy.willValidate}get labels(){if(this.elementInternals)return Object.freeze(Array.from(this.elementInternals.labels));if(this.proxy instanceof HTMLElement&&this.proxy.ownerDocument&&this.id){const e=this.proxy.labels,t=Array.from(this.proxy.getRootNode().querySelectorAll(`[for='${this.id}']`)),r=e?t.concat(Array.from(e)):t;return Object.freeze(r)}return s.ow}valueChanged(e,t){this.dirtyValue=!0,this.proxy instanceof HTMLElement&&(this.proxy.value=this.value),this.currentValue=this.value,this.setFormValue(this.value),this.validate()}currentValueChanged(){this.value=this.currentValue}initialValueChanged(e,t){this.dirtyValue||(this.value=this.initialValue,this.dirtyValue=!1)}disabledChanged(e,t){this.proxy instanceof HTMLElement&&(this.proxy.disabled=this.disabled),n.SO.queueUpdate((()=>this.classList.toggle("disabled",this.disabled)))}nameChanged(e,t){this.proxy instanceof HTMLElement&&(this.proxy.name=this.name)}requiredChanged(e,t){this.proxy instanceof HTMLElement&&(this.proxy.required=this.required),n.SO.queueUpdate((()=>this.classList.toggle("required",this.required))),this.validate()}get elementInternals(){if(!h)return null;let e=c.get(this);return e||(e=this.attachInternals(),c.set(this,e)),e}connectedCallback(){super.connectedCallback(),this.addEventListener("keypress",this._keypressHandler),this.value||(this.value=this.initialValue,this.dirtyValue=!1),this.elementInternals||(this.attachProxy(),this.form&&this.form.addEventListener("reset",this.formResetCallback))}disconnectedCallback(){super.disconnectedCallback(),this.proxyEventsToBlock.forEach((e=>this.proxy.removeEventListener(e,this.stopPropagation))),!this.elementInternals&&this.form&&this.form.removeEventListener("reset",this.formResetCallback)}checkValidity(){return this.elementInternals?this.elementInternals.checkValidity():this.proxy.checkValidity()}reportValidity(){return this.elementInternals?this.elementInternals.reportValidity():this.proxy.reportValidity()}setValidity(e,t,r){this.elementInternals?this.elementInternals.setValidity(e,t,r):"string"==typeof t&&this.proxy.setCustomValidity(t)}formDisabledCallback(e){this.disabled=e}formResetCallback(){this.value=this.initialValue,this.dirtyValue=!1}attachProxy(){var e;this.proxyInitialized||(this.proxyInitialized=!0,this.proxy.style.display="none",this.proxyEventsToBlock.forEach((e=>this.proxy.addEventListener(e,this.stopPropagation))),this.proxy.disabled=this.disabled,this.proxy.required=this.required,"string"==typeof this.name&&(this.proxy.name=this.name),"string"==typeof this.value&&(this.proxy.value=this.value),this.proxy.setAttribute("slot",l),this.proxySlot=document.createElement("slot"),this.proxySlot.setAttribute("name",l)),null===(e=this.shadowRoot)||void 0===e||e.appendChild(this.proxySlot),this.appendChild(this.proxy)}detachProxy(){var e;this.removeChild(this.proxy),null===(e=this.shadowRoot)||void 0===e||e.removeChild(this.proxySlot)}validate(e){this.proxy instanceof HTMLElement&&this.setValidity(this.proxy.validity,this.proxy.validationMessage,e)}setFormValue(e,t){this.elementInternals&&this.elementInternals.setFormValue(e,t||e)}_keypressHandler(e){if(e.key===a.kL&&this.form instanceof HTMLFormElement){const e=this.form.querySelector("[type=submit]");null==e||e.click()}}stopPropagation(e){e.stopPropagation()}};return(0,i.Lj)({mode:"boolean"})(t.prototype,"disabled"),(0,i.Lj)({mode:"fromView",attribute:"value"})(t.prototype,"initialValue"),(0,i.Lj)({attribute:"current-value"})(t.prototype,"currentValue"),(0,i.Lj)(t.prototype,"name"),(0,i.Lj)({mode:"boolean"})(t.prototype,"required"),(0,o.LO)(t.prototype,"value"),t}},50755:(e,t,r)=>{r.d(t,{I:()=>a,R:()=>u});var s=r(95185),n=r(58930),i=r(92221),o=r(40791);class a extends n.H{constructor(){super(...arguments),this._presentation=void 0}get $presentation(){return void 0===this._presentation&&(this._presentation=o.v.forTag(this.tagName,this)),this._presentation}templateChanged(){void 0!==this.template&&(this.$fastController.template=this.template)}stylesChanged(){void 0!==this.styles&&(this.$fastController.styles=this.styles)}connectedCallback(){null!==this.$presentation&&this.$presentation.applyTo(this),super.connectedCallback()}static compose(e){return(t={})=>new u(this===a?class extends a{}:this,e,t)}}function l(e,t,r){return"function"==typeof e?e(t,r):e}(0,s.gn)([i.LO],a.prototype,"template",void 0),(0,s.gn)([i.LO],a.prototype,"styles",void 0);class u{constructor(e,t,r){this.type=e,this.elementDefinition=t,this.overrideDefinition=r,this.definition=Object.assign(Object.assign({},this.elementDefinition),this.overrideDefinition)}register(e,t){const r=this.definition,s=this.overrideDefinition,n=`${r.prefix||t.elementPrefix}-${r.baseName}`;t.tryDefineElement({name:n,type:this.type,baseClass:this.elementDefinition.baseClass,callback:e=>{const t=new o.B(l(r.template,e,r),l(r.styles,e,r));e.definePresentation(t);let n=l(r.shadowOptions,e,r);e.shadowRootMode&&(n?s.shadowOptions||(n.mode=e.shadowRootMode):null!==n&&(n={mode:e.shadowRootMode})),e.defineElement({elementOptions:l(r.elementOptions,e,r),shadowOptions:n,attributes:l(r.attributes,e,r)})}})}}},14869:(e,t,r)=>{r.d(t,{v:()=>i});var s=r(95185),n=r(98332);class i{}(0,s.gn)([(0,n.Lj)({attribute:"aria-atomic"})],i.prototype,"ariaAtomic",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-busy"})],i.prototype,"ariaBusy",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-controls"})],i.prototype,"ariaControls",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-current"})],i.prototype,"ariaCurrent",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-describedby"})],i.prototype,"ariaDescribedby",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-details"})],i.prototype,"ariaDetails",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-disabled"})],i.prototype,"ariaDisabled",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-errormessage"})],i.prototype,"ariaErrormessage",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-flowto"})],i.prototype,"ariaFlowto",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-haspopup"})],i.prototype,"ariaHaspopup",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-hidden"})],i.prototype,"ariaHidden",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-invalid"})],i.prototype,"ariaInvalid",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-keyshortcuts"})],i.prototype,"ariaKeyshortcuts",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-label"})],i.prototype,"ariaLabel",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-labelledby"})],i.prototype,"ariaLabelledby",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-live"})],i.prototype,"ariaLive",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-owns"})],i.prototype,"ariaOwns",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-relevant"})],i.prototype,"ariaRelevant",void 0),(0,s.gn)([(0,n.Lj)({attribute:"aria-roledescription"})],i.prototype,"ariaRoledescription",void 0)},52865:(e,t,r)=>{r.d(t,{LC:()=>o,hW:()=>i,m9:()=>a});var s=r(25269),n=r(62564);class i{handleStartContentChange(){this.startContainer.classList.toggle("start",this.start.assignedNodes().length>0)}handleEndContentChange(){this.endContainer.classList.toggle("end",this.end.assignedNodes().length>0)}}const o=(e,t)=>s.d`
    <span
        part="end"
        ${(0,n.i)("endContainer")}
        class=${e=>t.end?"end":void 0}
    >
        <slot name="end" ${(0,n.i)("end")} @slotchange="${e=>e.handleEndContentChange()}">
            ${t.end||""}
        </slot>
    </span>
`,a=(e,t)=>s.d`
    <span
        part="start"
        ${(0,n.i)("startContainer")}
        class="${e=>t.start?"start":void 0}"
    >
        <slot
            name="start"
            ${(0,n.i)("start")}
            @slotchange="${e=>e.handleStartContentChange()}"
        >
            ${t.start||""}
        </slot>
    </span>
`;s.d`
    <span part="end" ${(0,n.i)("endContainer")}>
        <slot
            name="end"
            ${(0,n.i)("end")}
            @slotchange="${e=>e.handleEndContentChange()}"
        ></slot>
    </span>
`,s.d`
    <span part="start" ${(0,n.i)("startContainer")}>
        <slot
            name="start"
            ${(0,n.i)("start")}
            @slotchange="${e=>e.handleStartContentChange()}"
        ></slot>
    </span>
`},89155:(e,t,r)=>{r.d(t,{e:()=>n});var s=r(98332);function n(e,...t){const r=s.Ax.locate(e);t.forEach((t=>{Object.getOwnPropertyNames(t.prototype).forEach((r=>{"constructor"!==r&&Object.defineProperty(e.prototype,r,Object.getOwnPropertyDescriptor(t.prototype,r))})),s.Ax.locate(t).forEach((e=>r.push(e)))}))}},75494:(e,t,r)=>{function s(e){const t=e.parentElement;if(t)return t;{const t=e.getRootNode();if(t.host instanceof HTMLElement)return t.host}return null}r.d(t,{T:()=>s})},98242:(e,t,r)=>{r.d(t,{vF:()=>i});class s{constructor(e){this.listenerCache=new WeakMap,this.query=e}bind(e){const{query:t}=this,r=this.constructListener(e);r.bind(t)(),t.addListener(r),this.listenerCache.set(e,r)}unbind(e){const t=this.listenerCache.get(e);t&&(this.query.removeListener(t),this.listenerCache.delete(e))}}class n extends s{constructor(e,t){super(e),this.styles=t}static with(e){return t=>new n(e,t)}constructListener(e){let t=!1;const r=this.styles;return function(){const{matches:s}=this;s&&!t?(e.$fastController.addStyles(r),t=s):!s&&t&&(e.$fastController.removeStyles(r),t=s)}}unbind(e){super.unbind(e),e.$fastController.removeStyles(this.styles)}}const i=n.with(window.matchMedia("(forced-colors)"));n.with(window.matchMedia("(prefers-color-scheme: dark)")),n.with(window.matchMedia("(prefers-color-scheme: light)"))},61424:(e,t,r)=>{r.d(t,{H:()=>s});const s="not-allowed"},78885:(e,t,r)=>{r.d(t,{j:()=>n});const s=":host([hidden]){display:none}";function n(e){return`${s}:host{display:${e}}`}},53405:(e,t,r)=>{let s;r.d(t,{b:()=>n});const n=function(){if("boolean"==typeof s)return s;if("undefined"==typeof window||!window.document||!window.document.createElement)return s=!1,s;const e=document.createElement("style"),t=function(){const e=document.querySelector('meta[property="csp-nonce"]');return e?e.getAttribute("content"):null}();null!==t&&e.setAttribute("nonce",t),document.head.appendChild(e);try{e.sheet.insertRule("foo:focus-visible {color:inherit}",0),s=!0}catch(e){s=!1}finally{document.head.removeChild(e)}return s}()?"focus-visible":"focus"},95185:(e,t,r)=>{function s(e,t,r,s){var n,i=arguments.length,o=i<3?t:null===s?s=Object.getOwnPropertyDescriptor(t,r):s;if("object"==typeof Reflect&&"function"==typeof Reflect.decorate)o=Reflect.decorate(e,t,r,s);else for(var a=e.length-1;a>=0;a--)(n=e[a])&&(o=(i<3?n(o):i>3?n(t,r,o):n(t,r))||o);return i>3&&o&&Object.defineProperty(t,r,o),o}r.d(t,{gn:()=>s})},27081:(e,t,r)=>{var s;r.d(t,{kL:()=>n,uf:()=>i}),function(e){e[e.alt=18]="alt",e[e.arrowDown=40]="arrowDown",e[e.arrowLeft=37]="arrowLeft",e[e.arrowRight=39]="arrowRight",e[e.arrowUp=38]="arrowUp",e[e.back=8]="back",e[e.backSlash=220]="backSlash",e[e.break=19]="break",e[e.capsLock=20]="capsLock",e[e.closeBracket=221]="closeBracket",e[e.colon=186]="colon",e[e.colon2=59]="colon2",e[e.comma=188]="comma",e[e.ctrl=17]="ctrl",e[e.delete=46]="delete",e[e.end=35]="end",e[e.enter=13]="enter",e[e.equals=187]="equals",e[e.equals2=61]="equals2",e[e.equals3=107]="equals3",e[e.escape=27]="escape",e[e.forwardSlash=191]="forwardSlash",e[e.function1=112]="function1",e[e.function10=121]="function10",e[e.function11=122]="function11",e[e.function12=123]="function12",e[e.function2=113]="function2",e[e.function3=114]="function3",e[e.function4=115]="function4",e[e.function5=116]="function5",e[e.function6=117]="function6",e[e.function7=118]="function7",e[e.function8=119]="function8",e[e.function9=120]="function9",e[e.home=36]="home",e[e.insert=45]="insert",e[e.menu=93]="menu",e[e.minus=189]="minus",e[e.minus2=109]="minus2",e[e.numLock=144]="numLock",e[e.numPad0=96]="numPad0",e[e.numPad1=97]="numPad1",e[e.numPad2=98]="numPad2",e[e.numPad3=99]="numPad3",e[e.numPad4=100]="numPad4",e[e.numPad5=101]="numPad5",e[e.numPad6=102]="numPad6",e[e.numPad7=103]="numPad7",e[e.numPad8=104]="numPad8",e[e.numPad9=105]="numPad9",e[e.numPadDivide=111]="numPadDivide",e[e.numPadDot=110]="numPadDot",e[e.numPadMinus=109]="numPadMinus",e[e.numPadMultiply=106]="numPadMultiply",e[e.numPadPlus=107]="numPadPlus",e[e.openBracket=219]="openBracket",e[e.pageDown=34]="pageDown",e[e.pageUp=33]="pageUp",e[e.period=190]="period",e[e.print=44]="print",e[e.quote=222]="quote",e[e.scrollLock=145]="scrollLock",e[e.shift=16]="shift",e[e.space=32]="space",e[e.tab=9]="tab",e[e.tilde=192]="tilde",e[e.windowsLeft=91]="windowsLeft",e[e.windowsOpera=219]="windowsOpera",e[e.windowsRight=92]="windowsRight"}(s||(s={}));const n="Enter",i={ArrowDown:"ArrowDown",ArrowLeft:"ArrowLeft",ArrowRight:"ArrowRight",ArrowUp:"ArrowUp"}},6618:(e,t,r)=>{var s;r.d(t,{N:()=>s}),function(e){e.ltr="ltr",e.rtl="rtl"}(s||(s={}))},30550:(e,t,r)=>{var s;r.d(t,{H:()=>s}),function(e){e.Canvas="Canvas",e.CanvasText="CanvasText",e.LinkText="LinkText",e.VisitedText="VisitedText",e.ActiveText="ActiveText",e.ButtonFace="ButtonFace",e.ButtonText="ButtonText",e.Field="Field",e.FieldText="FieldText",e.Highlight="Highlight",e.HighlightText="HighlightText",e.GrayText="GrayText"}(s||(s={}))},82616:(e,t,r)=>{function s(e,t,r,s){var n,i=arguments.length,o=i<3?t:null===s?s=Object.getOwnPropertyDescriptor(t,r):s;if("object"==typeof Reflect&&"function"==typeof Reflect.decorate)o=Reflect.decorate(e,t,r,s);else for(var a=e.length-1;a>=0;a--)(n=e[a])&&(o=(i<3?n(o):i>3?n(t,r,o):n(t,r))||o);return i>3&&o&&Object.defineProperty(t,r,o),o}r.d(t,{gn:()=>s}),Object.create,Object.create,"function"==typeof SuppressedError&&SuppressedError}}]);